import pytest

from sentencex import segment

# ruff: noqa: E501
tests = [
    ("¿Cómo está hoy? Espero que muy bien.", ["¿Cómo está hoy?", "Espero que muy bien."]),
    ("¡Hola señorita! Espero que muy bien.", ["¡Hola señorita!", "Espero que muy bien."]),
    (
        "Hola Srta. Ledesma. Buenos días, soy el Lic. Naser Pastoriza, y él es mi padre, el Dr. Naser.",
        [
            "Hola Srta. Ledesma.",
            "Buenos días, soy el Lic. Naser Pastoriza, y él es mi padre, el Dr. Naser.",
        ],
    ),
    (
        "¡La casa cuesta $170.500.000,00! ¡Muy costosa! Se prevé una disminución del 12.5% para el próximo año.",
        [
            "¡La casa cuesta $170.500.000,00!",
            "¡Muy costosa!",
            "Se prevé una disminución del 12.5% para el próximo año.",
        ],
    ),
    (
        "«Ninguna mente extraordinaria está exenta de un toque de demencia.», dijo Aristóteles.",
        ["«Ninguna mente extraordinaria está exenta de un toque de demencia.», dijo Aristóteles."],
    ),
    (
        "«Ninguna mente extraordinaria está exenta de un toque de demencia», dijo Aristóteles. Pablo, ¿adónde vas? ¡¿Qué viste?!",
        [
            "«Ninguna mente extraordinaria está exenta de un toque de demencia», dijo Aristóteles.",
            "Pablo, ¿adónde vas?",
            "¡¿Qué viste?!",
        ],
    ),
    ("Admón. es administración o me equivoco.", ["Admón. es administración o me equivoco."]),
    (
        "¡Hola Srta. Ledesma! ¿Cómo está hoy? Espero que muy bien.",
        ["¡Hola Srta. Ledesma!", "¿Cómo está hoy?", "Espero que muy bien."],
    ),
    (
        "Buenos días, soy el Lic. Naser Pastoriza, y él es mi padre, el Dr. Naser.",
        ["Buenos días, soy el Lic. Naser Pastoriza, y él es mi padre, el Dr. Naser."],
    ),
    (
        "He apuntado una cita para la siguiente fecha: Mar. 23 de Nov. de 2014. Gracias.",
        ["He apuntado una cita para la siguiente fecha: Mar. 23 de Nov. de 2014.", "Gracias."],
    ),
    (
        "Núm. de tel: 351.123.465.4. Envíe mis saludos a la Sra. Rescia.",
        ["Núm. de tel: 351.123.465.4.", "Envíe mis saludos a la Sra. Rescia."],
    ),
    (
        "Cero en la escala Celsius o de grados centígrados (0 °C) se define como el equivalente a 273.15 K, con una diferencia de temperatura de 1 °C equivalente a una diferencia de 1 Kelvin. Esto significa que 100 °C, definido como el punto de ebullición del agua, se define como el equivalente a 373.15 K.",
        [
            "Cero en la escala Celsius o de grados centígrados (0 °C) se define como el equivalente a 273.15 K, con una diferencia de temperatura de 1 °C equivalente a una diferencia de 1 Kelvin.",
            "Esto significa que 100 °C, definido como el punto de ebullición del agua, se define como el equivalente a 373.15 K.",
        ],
    ),
    (
        "Durante la primera misión del Discovery (30 Ago. 1984 15:08.10) tuvo lugar el lanzamiento de dos satélites de comunicación, el nombre de esta misión fue STS-41-D.",
        [
            "Durante la primera misión del Discovery (30 Ago. 1984 15:08.10) tuvo lugar el lanzamiento de dos satélites de comunicación, el nombre de esta misión fue STS-41-D."
        ],
    ),
    (
        'Frase del gran José Hernández: "Aquí me pongo a cantar / al compás de la vigüela, / que el hombre que lo desvela / una pena estrordinaria, / como la ave solitaria / con el cantar se consuela. / [...] ".',
        [
            'Frase del gran José Hernández: "Aquí me pongo a cantar / al compás de la vigüela, / que el hombre que lo desvela / una pena estrordinaria, / como la ave solitaria / con el cantar se consuela. / [...] ".'
        ],
    ),
    (
        "Citando a Criss Jami «Prefiero ser un artista a ser un líder, irónicamente, un líder tiene que seguir las reglas.», lo cual parece muy acertado.",
        [
            "Citando a Criss Jami «Prefiero ser un artista a ser un líder, irónicamente, un líder tiene que seguir las reglas.», lo cual parece muy acertado."
        ],
    ),
    (
        'Cuando llegué, le estaba dando ejercicios a los niños, uno de los cuales era "3 + (14/7).x = 5". ¿Qué te parece?',
        [
            'Cuando llegué, le estaba dando ejercicios a los niños, uno de los cuales era "3 + (14/7).x = 5".',
            "¿Qué te parece?",
        ],
    ),
    pytest.param(
        "Se le pidió a los niños que leyeran los párrf. 5 y 6 del art. 4 de la constitución de los EE. UU..",
        [
            "Se le pidió a los niños que leyeran los párrf. 5 y 6 del art. 4 de la constitución de los EE. UU.."
        ],
        marks=pytest.mark.xfail,
    ),
    (
        'Una de las preguntas realizadas en la evaluación del día Lun. 15 de Mar. fue la siguiente: "Alumnos, ¿cuál es el resultado de la operación 1.1 + 4/5?". Disponían de 1 min. para responder esa pregunta.',
        [
            'Una de las preguntas realizadas en la evaluación del día Lun. 15 de Mar. fue la siguiente: "Alumnos, ¿cuál es el resultado de la operación 1.1 + 4/5?".',
            "Disponían de 1 min. para responder esa pregunta.",
        ],
    ),
    (
        "La temperatura del motor alcanzó los 120.5°C. Afortunadamente, pudo llegar al final de carrera.",
        [
            "La temperatura del motor alcanzó los 120.5°C.",
            "Afortunadamente, pudo llegar al final de carrera.",
        ],
    ),
    (
        "El volumen del cuerpo es 3m³. ¿Cuál es la superficie de cada cara del prisma?",
        ["El volumen del cuerpo es 3m³.", "¿Cuál es la superficie de cada cara del prisma?"],
    ),
    (
        "La habitación tiene 20.55m². El living tiene 50.0m².",
        ["La habitación tiene 20.55m².", "El living tiene 50.0m²."],
    ),
    (
        "1°C corresponde a 33.8°F. ¿A cuánto corresponde 35°C?",
        ["1°C corresponde a 33.8°F.", "¿A cuánto corresponde 35°C?"],
    ),
    (
        "Hamilton ganó el último gran premio de Fórmula 1, luego de 1:39:02.619 Hs. de carrera, segundo resultó Massa, a una diferencia de 2.5 segundos. De esta manera se consagró ¡Campeón mundial!",
        [
            "Hamilton ganó el último gran premio de Fórmula 1, luego de 1:39:02.619 Hs. de carrera, segundo resultó Massa, a una diferencia de 2.5 segundos.",
            "De esta manera se consagró ¡Campeón mundial!",
        ],
    ),
    (
        "¡La casa cuesta $170.500.000,00! ¡Muy costosa! Se prevé una disminución del 12.5% para el próximo año.",
        [
            "¡La casa cuesta $170.500.000,00!",
            "¡Muy costosa!",
            "Se prevé una disminución del 12.5% para el próximo año.",
        ],
    ),
    ("El corredor No. 103 arrivó 4°.", ["El corredor No. 103 arrivó 4°."]),
    (
        "Hoy es 27/04/2014, y es mi cumpleaños. ¿Cuándo es el tuyo?",
        ["Hoy es 27/04/2014, y es mi cumpleaños.", "¿Cuándo es el tuyo?"],
    ),
    pytest.param(
        "Aquí está la lista de compras para el almuerzo: 1.Helado, 2.Carne, 3.Arroz. ¿Cuánto costará? Quizás $12.5.",
        [
            "Aquí está la lista de compras para el almuerzo: 1.Helado, 2.Carne, 3.Arroz.",
            "¿Cuánto costará?",
            "Quizás $12.5.",
        ],
        marks=pytest.mark.xfail,
    ),
    (
        "1 + 1 es 2. 2 + 2 es 4. El auto es de color rojo.",
        ["1 + 1 es 2.", "2 + 2 es 4.", "El auto es de color rojo."],
    ),
    (
        "La máquina viajaba a 100 km/h. ¿En cuánto tiempo recorrió los 153 Km.?",
        ["La máquina viajaba a 100 km/h.", "¿En cuánto tiempo recorrió los 153 Km.?"],
    ),
    (
        "Explora oportunidades de carrera en el área de Salud en el Hospital de Northern en Mt. Kisco.",
        [
            "Explora oportunidades de carrera en el área de Salud en el Hospital de Northern en Mt. Kisco."
        ],
    ),
]


@pytest.mark.parametrize("text,expected_sents", tests)
def test_segment(text, expected_sents):
    assert list(segment("es", text)) == expected_sents



# unicode code points with the \p{Sentence_Break=STerm} or \p{Sentence_Break=ATerm} properties that
# also have the \p{Terminal_Punctuation} property generated with Unicode::Tussle perl script and
# additional fullstops in unicode character sets : https://www.fileformat.info/info/unicode/char/search.htm?q=.&
# preview=entity
GLOBAL_SENTENCE_TERMINATORS = [
    "...",  # Horizontal Ellipsis
    "!",  # Exclamation Mark
    ".",  # Full Stop
    "?",  # Question Mark
    "։",  # Armenian Full Stop
    "؞",  # Arabic Sign Sallallahou Alayhe Wasallam
    "؟",  # Arabic Question Mark
    "۔",  # Arabic Full Stop
    "܀",  # Syriac End of Paragraph
    "܁",  # Syriac Supralinear Colon
    "܂",  # Syriac Sublinear Colon
    "߹",  # Nko Symbol Doorye
    "࠷",  # Samarkan Letter Do
    "࠹",  # Samarkan Letter Jho
    "࠽",  # Samarkan Letter Ro
    "࠾",  # Samarkan Letter Lo
    "।",  # Devanagari Danda
    "॥",  # Devanagari Double Danda
    "၊",  # Myanmar Sign Myanmar Phrase Stop
    "။",  # Myanmar Sign Myanmar Paragraph
    "።",  # Ethiopic Full Stop
    "፧",  # Ethiopic Colon
    "፨",  # Ethiopic Preface Colon
    "᙮",  # Ethiopic Question Mark
    "᜵",  # Buginese Vowel Sign E
    "᜶",  # Buginese Vowel Sign O
    "᠃",  # Mongolian Full Stop
    "᠉",  # Mongolian Birga
    "᥄",  # Buhid Virama
    "᥅",  # Buhid Punctuation Mark
    "᪨",  # Tai Tham Consonant Sign Medial Ra
    "᪩",  # Tai Tham Consonant Sign Medial La
    "᪪",  # Tai Tham Consonant Sign La Taa
    "᪫",  # Tai Tham Sign Mai Sak
    "᭚",  # Balinese Pameneng
    "᭛",  # Balinese Musical Symbol Combining Jublag
    "᭞",  # Sundanese Padasan Agung
    "᭟",  # Sundanese Paneken
    "᰻",  # Buhid Pamudpod
    "᰼",  # Buhid Pamudpod Han
    "᱾",  # Limbu Question Mark
    "᱿",  # Limbu Exclamation Mark
    "‼",  # Double Exclamation Mark
    "‽",  # Interrobang
    "⁇",  # Double Question Mark
    "⁈",  # Question Exclamation Mark
    "⁉",  # Exclamation Question Mark
    "⸮",  # Reversed Question Mark
    "⸼",  # Armenian Parenthesis Right
    "꓿",  # Yi Punctuation Small Comma
    "꘎",  # Vai Comma
    "꘏",  # Vai Full Stop
    "꛳",  # Batak Apostrophe
    "꛷",  # Batak Pangolat
    "꡶",  # Lanna Punctation Phrase
    "꡷",  # Lanna Punctation Paragraph
    "꣎",  # Ol Chiki Punctuation Mucaad
    "꣏",  # Ol Chiki Punctuation Double
    "꤯",  # Chakma Sign Visarga
    "꧈",  # Balinese Musical Symbol Left-Hand Open Dug
    "꧉",  # Balinese Musical Symbol Right-Hand Open Dug
    "꩝",  # Cham Consonant Sign Final H
    "꩞",  # Cham Consonant Sign Glottal Stop
    "꩟",  # Cham Consonant Sign M
    "꫰",  # Tai Viet Mai Khit
    "꫱",  # Tai Viet Vowel Ia
    "꯫",  # Meetei Mayek Cheikhei
    "﹒",  # Small Full Stop
    "﹖",  # Small Question Mark
    "﹗",  # Small Exclamation Mark
    "！",  # Fullwidth Exclamation Mark
    "．",  # Fullwidth Full Stop
    "？",  # Fullwidth Question Mark
    "ཕ",  # Tibetan Letter Pha
    "བ",  # Tibetan Letter Ba
    "བྷ",  # Tibetan Letter Bha
    "མ",  # Tibetan Letter Ma
    "ཙ",  # Tibetan Letter Tsa
    "၇",  # Myanmar Digit Seven
    "၈",  # Myanmar Digit Eight
    "Ⴞ",  # Georgian Letter Har
    "Ⴟ",  # Georgian Letter Hae
    "Ⴠ",  # Georgian Letter Hoe
    "Ⴡ",  # Georgian Letter Yu
    "ᅁ",  # Hangul Letter Yeorin Hieuh
    "ᅂ",  # Hangul Letter Yeorin Simeum
    "ᅃ",  # Hangul Letter Yeorin Cieuc
    "ᇅ",  # Hangul Letter Phieuph-Pieup
    "ᇆ",  # Hangul Letter Kapyeounphieuph
    "ᇍ",  # Hangul Letter Kapyeounhieuh
    "ᇞ",  # Hangul Letter Yang-Hieuh
    "ᇟ",  # Hangul Letter Yo-Yae
    "ሸ",  # Ethiopic Syllable Shee
    "ሹ",  # Ethiopic Syllable Shuu
    "ሻ",  # Ethiopic Syllable Shaa
    "ሼ",  # Ethiopic Syllable She
    "ኩ",  # Ethiopic Syllable Ku
    "ᑋ",  # Canadian Syllabics We
    "ᑌ",  # Canadian Syllabics West-Cree Pa
    "ᗂ",  # Canadian Syllabics South Slavey Lo
    "ᗃ",  # Canadian Syllabics South Slavey Lu
    "ᗉ",  # Canadian Syllabics Carrier Syllabic Yay
    "ᗊ",  # Canadian Syllabics Carrier Syllabic Yaa
    "ᗋ",  # Canadian Syllabics Carrier Syllabic Ywe
    "ᗌ",  # Canadian Syllabics Carrier Syllabic Ywi
    "ᗍ",  # Canadian Syllabics Carrier Syllabic Ywii
    "ᗎ",  # Canadian Syllabics Carrier Syllabic Ywo
    "ᗏ",  # Canadian Syllabics Carrier Syllabic Ywoo
    "ᗐ",  # Canadian Syllabics Carrier Syllabic Ywi
    "ᗗ",  # Canadian Syllabics Cree-Cha
    "ᙁ",  # Canadian Syllabics Slavey She
    "ᙂ",  # Canadian Syllabics Chipewyan Ga
    "᥄",  # Ethiopic Syllable Gwa
    "᥆",  # Ethiopic Syllable Gwo
    "ᩂ",  # Tai Tham Consonant Sign Low Ha
    "ᩃ",  # Tai Tham Consonant Sign High Ha
    "᱁",  # Ethiopic Syllable Hoa
    "᱂",  # Ethiopic Syllable Hoa
    "ỷ",  # Latin Small Letter Y With Tilde
    "Ỹ",  # Latin Capital Letter Y With Tilde
    "橮",  # CJK Unified Ideograph-6AEE
    "橯",  # CJK Unified Ideograph-6AEF
    "櫵",  # CJK Unified Ideograph-6AF5
    "欷",  # CJK Unified Ideograph-6B37
    "欸",  # CJK Unified Ideograph-6B38
    "歄",  # CJK Unified Ideograph-6B84
    "溘",  # CJK Unified Ideograph-6E98
    "벟",  # Hangul Syllable Eq
    "⳹",  # Greek Small Letter Ous
    "⳾",  # Greek Small Letter Psi
    "。",  # Ideographic Full Stop
    "︒",  # Presentation Form For Vertical Ideographic Full Stop
    "｡",  # Halfwidth Katakana Middle Dot
    "𖫵",  # Mongolian Vowel Separator
    "𖺘",  # Mongolian Letter Ali Gali U
    "𛲟",  # Hanifi Rohingya Sign Harbahay
    "𝪈",  # Mathematical Bold Capital U
]  # 150 symbols



import pytest

from sentencex import segment

# ruff: noqa: E501

tests = [
    ("Ի՞նչ ես մտածում: Ոչինչ:", ["Ի՞նչ ես մտածում:", "Ոչինչ:"]),
    (
        "Ապրիլի 24-ին սկսեց անձրևել...Այդպես էի գիտեի:",
        ["Ապրիլի 24-ին սկսեց անձրևել...Այդպես էի գիտեի:"],
    ),
    (
        "Այսպիսով` մոտենում ենք ավարտին: Տրամաբանությյունը հետևյալն է. պարզություն և աշխատանք:",
        [
            "Այսպիսով` մոտենում ենք ավարտին:",
            "Տրամաբանությյունը հետևյալն է. պարզություն և աշխատանք:",
        ],
    ),
    (
        "Սա այն փուլն է, երբ տեղի է ունենում Համակարգի մշակումը: Համաձայն Փուլ 2-ի, Մատակարարը մշակում և/կամ հարմարեցնում է համապատասխան ծրագիրը, տեղադրում ծրագրի բաղկացուցիչները, կատարում առանձին բլոկի և համակարգի թեստավորում և ներառում տարբեր մոդուլներ եզակի աշխատանքային համակարգում, որը  կազմում է այս Փուլի արդյունքը:",
        [
            "Սա այն փուլն է, երբ տեղի է ունենում Համակարգի մշակումը:",
            "Համաձայն Փուլ 2-ի, Մատակարարը մշակում և/կամ հարմարեցնում է համապատասխան ծրագիրը, տեղադրում ծրագրի բաղկացուցիչները, կատարում առանձին բլոկի և համակարգի թեստավորում և ներառում տարբեր մոդուլներ եզակի աշխատանքային համակարգում, որը  կազմում է այս Փուլի արդյունքը:",
        ],
    ),
    (
        "Մատակարարի նախագծի անձնակազմի կողմից համակարգի թեստերը հաջող անցնելուց հետո, Համակարգը տրվում է Գնորդին թեստավորման համար: 2-րդ փուլում, հիմք ընդունելով թեստային սցենարիոները, թեստերը կատարվում են Կառավարության կողմից Մատակարարի աջակցությամբ: Այս թեստերի թիրախը հանդիսանում է  Համակարգի` որպես մեկ ամբողջության և համակարգի գործունեության ստուգումը համաձայն տեխնիկական բնութագրերի: Այս թեստերի հաջողակ ավարտից հետո, Համակարգը ժամանակավոր ընդունվում է  Կառավարության կողմից: Այս թեստերի արդյունքները փաստաթղթային ձևով կներակայացվեն Թեստային Արդյունքների Հաշվետվություններում: Մատակարարը պետք է տրամադրի հետևյալը`",
        [
            "Մատակարարի նախագծի անձնակազմի կողմից համակարգի թեստերը հաջող անցնելուց հետո, Համակարգը տրվում է Գնորդին թեստավորման համար:",
            "2-րդ փուլում, հիմք ընդունելով թեստային սցենարիոները, թեստերը կատարվում են Կառավարության կողմից Մատակարարի աջակցությամբ:",
            "Այս թեստերի թիրախը հանդիսանում է  Համակարգի` որպես մեկ ամբողջության և համակարգի գործունեության ստուգումը համաձայն տեխնիկական բնութագրերի:",
            "Այս թեստերի հաջողակ ավարտից հետո, Համակարգը ժամանակավոր ընդունվում է  Կառավարության կողմից:",
            "Այս թեստերի արդյունքները փաստաթղթային ձևով կներակայացվեն Թեստային Արդյունքների Հաշվետվություններում:",
            "Մատակարարը պետք է տրամադրի հետևյալը`",
        ],
    ),
    (
        "Մատակարարի նախագծի անձնակազմի կողմից համակարգի թեստերը հաջող անցնելուց հետո, Համակարգը տրվում է Գնորդին թեստավորման համար: 2-րդ փուլում, հիմք ընդունելով թեստային սցենարիոները, թեստերը կատարվում են Կառավարության կողմից Մատակարարի աջակցությամբ: Այս թեստերի թիրախը հանդիսանում է  Համակարգի` որպես մեկ ամբողջության և համակարգի գործունեության ստուգումը համաձայն տեխնիկական բնութագրերի: Այս թեստերի հաջողակ ավարտից հետո, Համակարգը ժամանակավոր ընդունվում է  Կառավարության կողմից: Այս թեստերի արդյունքները փաստաթղթային ձևով կներակայացվեն Թեստային Արդյունքների Հաշվետվություններում: Մատակարարը պետք է տրամադրի հետևյալը`",
        [
            "Մատակարարի նախագծի անձնակազմի կողմից համակարգի թեստերը հաջող անցնելուց հետո, Համակարգը տրվում է Գնորդին թեստավորման համար:",
            "2-րդ փուլում, հիմք ընդունելով թեստային սցենարիոները, թեստերը կատարվում են Կառավարության կողմից Մատակարարի աջակցությամբ:",
            "Այս թեստերի թիրախը հանդիսանում է  Համակարգի` որպես մեկ ամբողջության և համակարգի գործունեության ստուգումը համաձայն տեխնիկական բնութագրերի:",
            "Այս թեստերի հաջողակ ավարտից հետո, Համակարգը ժամանակավոր ընդունվում է  Կառավարության կողմից:",
            "Այս թեստերի արդյունքները փաստաթղթային ձևով կներակայացվեն Թեստային Արդյունքների Հաշվետվություններում:",
            "Մատակարարը պետք է տրամադրի հետևյալը`",
        ],
    ),
    # "Hello world. My name is Armine." ==> ["Hello world.", "My name is Armine."]
    ("Բարև Ձեզ: Իմ անունն էԱրմինե:", ["Բարև Ձեզ:", "Իմ անունն էԱրմինե:"]),
    # "Today is Monday. I am going to work." ==> ["Today is Monday.", "I am going to work."]
    (
        "Այսօր երկուշաբթի է: Ես գնում եմ աշխատանքի:",
        ["Այսօր երկուշաբթի է:", "Ես գնում եմ աշխատանքի:"],
    ),
    #  "Tomorrow is September 1st. We are going to school." ==> ["Tomorrow is September 1st.", "We are going to school."]
    (
        "Վաղը սեպտեմբերի 1-ն է: Մենք գնում ենք դպրոց:",
        ["Վաղը սեպտեմբերի 1-ն է:", "Մենք գնում ենք դպրոց:"],
    ),
    #  "Yes, I understood. I really love you." ==> ["Yes, I understood.", "I really love you."]
    (
        "Այո, ես հասկացա: Ես իսկապես քեզ սիրում եմ:",
        ["Այո, ես հասկացա:", "Ես իսկապես քեզ սիրում եմ:"],
    ),
    #  "Close the windows. It is raining in the evening." ==> ["Close the windows.", "It is raining in the evening."]
    ("Փակիր պատուհանները: Երեկոյան անձրևում է:", ["Փակիր պատուհանները:", "Երեկոյան անձրևում է:"]),
    #  "It is dark. I should go home." ==> ["It is dark.", "I should go home."]
    ("Մութ է: Ես պետք է տուն վերադառնամ:", ["Մութ է:", "Ես պետք է տուն վերադառնամ:"]),
    #  "You know, I am starting to believe. Everything is changing." ==> ["You know, I am starting to believe.", "Everything is changing."]
    (
        "Գիտես, սկսել եմ հավատալ: Ամեն ինչ փոխվում է:",
        ["Գիտես, սկսել եմ հավատալ:", "Ամեն ինչ փոխվում է:"],
    ),
    #  "It is a new Christmas tree. We should decorate it." ==> ["It is a new Christmas tree.", "We should decorate it."]
    ("Տոնածառը նոր է: Պետք է այն զարդարել:", ["Տոնածառը նոր է:", "Պետք է այն զարդարել:"]),
    #  "I am in hurry. I could not wait you." ==> ["I am in hurry.", "I could not wait you."]
    ("Ես շտապում եմ: Ես քեզ չեմ կարող սպասել:", ["Ես շտապում եմ:", "Ես քեզ չեմ կարող սպասել:"]),
    #  "Wait, we love each other. I want us to live together." ==> ["Wait, we love each other.", "I want us to live together."]
    (
        "Սպասիր, մենք իրար սիրում ենք: Ցանկանում եմ միասին ապրենք:",
        ["Սպասիր, մենք իրար սիրում ենք:", "Ցանկանում եմ միասին ապրենք:"],
    ),
    #  "No, I do not think so. It is not true." ==> ["No, I do not think so.", "It is not true."]
    ("Ոչ, այդպես չեմ կարծում: Դա ճիշտ չէ:", ["Ոչ, այդպես չեմ կարծում:", "Դա ճիշտ չէ:"]),
    #  "April 24 it has started to rain... I was thinking about." ==> ["April 24 it has started to rain... I was thinking about."]
    (
        "Ապրիլի 24-ին սկսեց անձրևել...Այդպես էի գիտեի:",
        ["Ապրիլի 24-ին սկսեց անձրևել...Այդպես էի գիտեի:"],
    ),
    #  "It was 1960...it was winter...it was night. It was cold...emptiness." ==> ["It was 1960...it was winter...it was night.", "It was cold...emptiness."]
    (
        "1960 թվական…ձմեռ…գիշեր: Սառն էր…դատարկություն:",
        ["1960 թվական…ձմեռ…գիշեր:", "Սառն էր…դատարկություն:"],
    ),
    #  "Why a computer could not do what a man could do? Simply it doesn't have a human brain." ==> ["Why a computer could not do what a man could do?", "Simply it doesn't have a human brain."]
    (
        "Ինչ՟ու այն, ինչ անում է մարդը, չի կարող անել համակարգիչը: Պարզապես չունի մարդկային ուղեղ:",
        [
            "Ինչ՟ու այն, ինչ անում է մարդը, չի կարող անել համակարգիչը:",
            "Պարզապես չունի մարդկային ուղեղ:",
        ],
    ),
    #  "Numerate for me 3 things that are important for you - I answer love, knowledge, sincerity." ==> ["Numerate for me 3 things that are important for you - I answer love, knowledge, sincerity."]
    (
        "Թվարկիր ինձ համար 3 բան, որ կարևոր է քեզ համար - Պատասխանում եմ. սեր, գիտելիք, ազնվություն:",
        [
            "Թվարկիր ինձ համար 3 բան, որ կարևոր է քեզ համար - Պատասխանում եմ. սեր, գիտելիք, ազնվություն:"
        ],
    ),
    #  "So, we are coming to the end. The logic is...simplicity and work" ==> ["So, we are coming to the end.", "Simplicity and work."]
    (
        "Այսպիսով` մոտենում ենք ավարտին: Տրամաբանությյունը հետևյալն է. պարզություն և աշխատանք:",
        [
            "Այսպիսով` մոտենում ենք ավարտին:",
            "Տրամաբանությյունը հետևյալն է. պարզություն և աշխատանք:",
        ],
    ),
    #  "What are you thinking? Nothing!" ==> ["What are you thinking?", "Nothing!"]
    ("Ի՞նչ ես մտածում: Ոչինչ:", ["Ի՞նչ ես մտածում:", "Ոչինչ:"]),
    #  "Can we work together ?. May be what you are thinking, is possible." ==> ["Can we work together?.", "May be what you are thinking is possible."]
    (
        "Կարող ե՞նք միասին աշխատել: Գուցե այն ինչ մտածում ես, իրականանալի է:",
        ["Կարող ե՞նք միասին աշխատել:", "Գուցե այն ինչ մտածում ես, իրականանալի է:"],
    ),
    #  "Now what we have started, comes to the end. However the questions are numerous... ." ==> ["Now what we have started, comes to the end.", "However the questions are numerous... ."]
    (
        "Հիմա, այն ինչ սկսել ենք, ավարտին է մոտենում: Հարցերը սակայն շատ են...:",
        ["Հիմա, այն ինչ սկսել ենք, ավարտին է մոտենում:", "Հարցերը սակայն շատ են...:"],
    ),
    #  "Honey... I am waiting. Shall I go... or?" ==> ["Honey... I am waiting.", "Shall I go... or?"]
    ("Սիրելիս...սպասում եմ: Գնամ թ՟ե …:", ["Սիրելիս...սպասում եմ:", "Գնամ թ՟ե …:"]),
]


@pytest.mark.parametrize("text,expected_sentences", tests)
def test_segment(text, expected_sentences):
    assert list(segment("hy", text)) == expected_sentences



import pytest

from sentencex import segment

# ruff: noqa: E501
tests = [
    (
        "Мұхитқа тікелей шыға алмайтын мемлекеттердің ішінде Қазақстан - ең үлкені.",
        ["Мұхитқа тікелей шыға алмайтын мемлекеттердің ішінде Қазақстан - ең үлкені."],
    ),
    pytest.param(
        "Оқушылар үйі, Достық даңғылы, Абай даналығы, ауыл шаруашылығы – кім? не?",
        ["Оқушылар үйі, Достық даңғылы, Абай даналығы, ауыл шаруашылығы – кім?", "не?"],
        marks=pytest.mark.xfail,
    ),
    (
        "Әр түрлі өлшемнің атауы болып табылатын м (метр), см (сантиметр), кг (киллограмм), т (тонна), га (гектар), ц (центнер), т. б. (тағы басқа), тәрізді белгілер де қысқарған сөздер болып табылады.",
        [
            "Әр түрлі өлшемнің атауы болып табылатын м (метр), см (сантиметр), кг (киллограмм), т (тонна), га (гектар), ц (центнер), т. б. (тағы басқа), тәрізді белгілер де қысқарған сөздер болып табылады."
        ],
    ),
    (
        "Мысалы: обкомға (облыстық комитетке) барды, ауаткомда (аудандық атқару комитетінде) болды, педучилищеге (педагогтік училищеге) түсті, медпункттің (медициналық пункттің) алдында т. б.",
        [
            "Мысалы: обкомға (облыстық комитетке) барды, ауаткомда (аудандық атқару комитетінде) болды, педучилищеге (педагогтік училищеге) түсті, медпункттің (медициналық пункттің) алдында т. б."
        ],
    ),
    (
        "Елдің жалпы ішкі өнімі ЖІӨ (номинал) = $225.619 млрд (2014)",
        ["Елдің жалпы ішкі өнімі ЖІӨ (номинал) = $225.619 млрд (2014)"],
    ),
    (
        "Ресейдiң әлеуметтiк-экономикалық жағдайы.XVIII ғасырдың бiрiншi ширегiнде Ресейге тән нәрсе.",
        [
            "Ресейдiң әлеуметтiк-экономикалық жағдайы.",
            "XVIII ғасырдың бiрiншi ширегiнде Ресейге тән нәрсе.",
        ],
    ),
    (
        "(«Егемен Қазақстан», 7 қыркүйек 2012 жыл. №590-591); Бұл туралы кеше санпедқадағалау комитетінің облыыстық департаменті хабарлады. («Айқын», 23 сəуір 2010 жыл. № 70).",
        [
            "(«Егемен Қазақстан», 7 қыркүйек 2012 жыл. №590-591); Бұл туралы кеше санпедқадағалау комитетінің облыыстық департаменті хабарлады.",
            "(«Айқын», 23 сəуір 2010 жыл. № 70).",
        ],
    ),
    (
        "Иран революциясы (1905 — 11) және азаматтық қозғалыс (1918 — 21) кезінде А. Фарахани, М. Кермани, М. Т. Бехар, т.б. ақындар демократиялық идеяның жыршысы болды.",
        [
            "Иран революциясы (1905 — 11) және азаматтық қозғалыс (1918 — 21) кезінде А. Фарахани, М. Кермани, М. Т. Бехар, т.б. ақындар демократиялық идеяның жыршысы болды."
        ],
    ),
    (
        "Владимир Федосеев: Аттар магиясы енді жоқ http://www.vremya.ru/2003/179/10/80980.html",
        ["Владимир Федосеев: Аттар магиясы енді жоқ http://www.vremya.ru/2003/179/10/80980.html"],
    ),
    ("Бірақ оның енді не керегі бар? — деді.", ["Бірақ оның енді не керегі бар? — деді."]),
    (
        "Сондықтан шапаныма жегізіп отырғаным! - деп, жауап береді.",
        ["Сондықтан шапаныма жегізіп отырғаным! - деп, жауап береді."],
    ),
    (
        "Б.з.б. 6 – 3 ғасырларда конфуцийшілдік, моизм, легизм мектептерінің қалыптасуы нәтижесінде Қытай философиясы пайда болды.",
        [
            "Б.з.б. 6 – 3 ғасырларда конфуцийшілдік, моизм, легизм мектептерінің қалыптасуы нәтижесінде Қытай философиясы пайда болды."
        ],
    ),
    (
        "'Та марбута' тек сөз соңында екі түрде жазылады:",
        ["'Та марбута' тек сөз соңында екі түрде жазылады:"],
    ),
]


@pytest.mark.parametrize("text,expected_sents", tests)
def test_segment(text, expected_sents):
    assert list(segment("kk", text)) == expected_sents



import pytest

from sentencex import segment

# ruff: noqa: E501

tests = [
    ("ခင္ဗ်ားနာမည္ဘယ္လိုေခၚလဲ။ င္ေနေကာင္းလား။", ["ခင္ဗ်ားနာမည္ဘယ္လိုေခၚလဲ။", "င္ေနေကာင္းလား။"])
]


@pytest.mark.parametrize("text,expected_sentences", tests)
def test_segment(text, expected_sentences):
    assert list(segment("my", text)) == expected_sentences



import pytest

from sentencex import segment

tests = [
    (
        "እንደምን አለህ፧መልካም ቀን ይሁንልህ።እባክሽ ያልሽዉን ድገሚልኝ።",
        ["እንደምን አለህ፧", "መልካም ቀን ይሁንልህ።", "እባክሽ ያልሽዉን ድገሚልኝ።"],
    ),
]


@pytest.mark.parametrize("text,expected_sentences", tests)
def test_segment(text, expected_sentences):
    assert list(segment("am", text)) == expected_sentences



import pytest

from sentencex import segment

# ruff: noqa: E501
tests = [
    (
        "Ide o majiteľov firmy ABTrade s. r. o., ktorí stoja aj za ďalšími spoločnosťami, napr. XYZCorp a.s.",
        [
            "Ide o majiteľov firmy ABTrade s. r. o., ktorí stoja aj za ďalšími spoločnosťami, napr. XYZCorp a.s."
        ],
    ),
    (
        "„Prieskumy beriem na ľahkú váhu. V podstate ma to nezaujíma,“ reagoval Matovič na prieskum agentúry Focus.",
        [
            "„Prieskumy beriem na ľahkú váhu. V podstate ma to nezaujíma,“ reagoval Matovič na prieskum agentúry Focus."
        ],
    ),
    (
        "Toto sa mi podarilo až na 10. pokus, ale stálo to za to.",
        ["Toto sa mi podarilo až na 10. pokus, ale stálo to za to."],
    ),
    (
        "Ide o príslušníkov XII. Pluku špeciálneho určenia.",
        ["Ide o príslušníkov XII. Pluku špeciálneho určenia."],
    ),
    (
        "Spoločnosť bola založená 7. Apríla 2020, na zmluve však figuruje dátum 20. marec 2020.",
        ["Spoločnosť bola založená 7. Apríla 2020, na zmluve však figuruje dátum 20. marec 2020."],
    ),
]


@pytest.mark.parametrize("text,expected_sents", tests)
def test_segment(text, expected_sents):
    assert list(segment("sk", text)) == expected_sents



import fileinput
from argparse import ArgumentParser

from sentencex import segment

if __name__ == "__main__":
    parser = ArgumentParser(prog="sentencex", description="Split the text to sentences")
    parser.add_argument("language")
    parser.add_argument(
        "files",
        metavar="FILE",
        nargs="*",
        help="Files to read, if empty, stdin is used",
    )
    args = parser.parse_args()
    for text in fileinput.input(files=args.files):
        sentences = segment(args.language, text)
        print(list(sentences))



import pytest

from sentencex import segment

tests = [
    ("ഇത് ഡോ. ശിവൻ. ഇദ്ദേഹമാണ് ഞാൻ പറഞ്ഞയാൾ", ["ഇത് ഡോ. ശിവൻ.", "ഇദ്ദേഹമാണ് ഞാൻ പറഞ്ഞയാൾ"]),
    ("ഇത് മി. കെ. പി. മോഹനൻ", ["ഇത് മി. കെ. പി. മോഹനൻ"]),
    ("ഇത് പ്രൊ. കെ.പി. മോഹനൻ", ["ഇത് പ്രൊ. കെ.പി. മോഹനൻ"]),
    ("ഇത് Dr. മോഹനൻ", ["ഇത് Dr. മോഹനൻ"]),
]


@pytest.mark.parametrize("text, expected_sents", tests)
def test_segment(text, expected_sents):
    assert list(segment("ml", text)) == expected_sents



import re

from sentencex.base import Language


class Italian(Language):
    language = "it"

    abbreviations = {
        "°c",
        "°f",
        "°n",
        "°ra",
        "°ré",
        "1°",
        "a.c",
        "a.c/a",
        "a.cam",
        "a.civ",
        "a.cor",
        "a.d.r",
        "a.gov",
        "a.mil",
        "a.mon",
        "a.smv",
        "a.v",
        "a/a",
        "a/c",
        "a/i",
        "aa",
        "aaaa",
        "aaal",
        "aacst",
        "aamct",
        "aams",
        "aar",
        "aato",
        "ab",
        "abbigl",
        "abbrev",
        "abc",
        "abi",
        "abl",
        "abm",
        "abr",
        "abs",
        "absp",
        "ac",
        "acam",
        "acb",
        "acbi",
        "acc",
        "accorc",
        "accr",
        "acd",
        "ace",
        "acec",
        "acep",
        "aci",
        "acli",
        "acp",
        "acro",
        "acsit",
        "actl",
        "ad.mil",
        "ad",
        "ada",
        "adap",
        "adatt",
        "adc",
        "add",
        "adei",
        "adeion",
        "adhd",
        "adi",
        "adisco",
        "adj",
        "adm",
        "adp",
        "adr",
        "ads",
        "adsi",
        "adsl",
        "adv",
        "ae.b",
        "aefi",
        "aer",
        "aerodin",
        "aeron",
        "afa",
        "afc",
        "afci",
        "affl",
        "afi",
        "afic",
        "afm",
        "afp",
        "ag",
        "agcm",
        "agcom",
        "age",
        "agecs",
        "agesci",
        "agg",
        "agip",
        "agis",
        "agm",
        "ago",
        "agr",
        "agric",
        "agt",
        "ai",
        "aia",
        "aiab",
        "aiac",
        "aiace",
        "aiap",
        "aias",
        "aiat",
        "aib",
        "aic",
        "aica",
        "aicel",
        "aici",
        "aics",
        "aid",
        "aida",
        "aidaa",
        "aidac",
        "aidama",
        "aidda",
        "aidim",
        "aido",
        "aids",
        "aies",
        "aif",
        "aih",
        "aiip",
        "aimi",
        "aip",
        "aipsc",
        "airi",
        "ais",
        "aisa",
        "aism",
        "aiss",
        "aissca",
        "aitc",
        "aiti",
        "aitr",
        "aits",
        "aka",
        "al",
        "alai",
        "alch",
        "alg",
        "ali",
        "alim",
        "all",
        "allev",
        "allus",
        "alp",
        "alq",
        "alt",
        "am",
        "amm",
        "ama",
        "amaci",
        "amag",
        "amami",
        "amc",
        "ammec",
        "amn",
        "ampas",
        "amps",
        "an",
        "ana",
        "anaai",
        "anac",
        "anaci",
        "anad",
        "anai",
        "anaoo",
        "anart",
        "anat. comp",
        "anat",
        "ancci",
        "anci",
        "ancip",
        "ancsa",
        "andit",
        "anec",
        "anee",
        "anem",
        "anes",
        "anffas",
        "ani",
        "ania",
        "anica",
        "anie",
        "animi",
        "anis",
        "anisc",
        "anm",
        "anmfit",
        "anmig",
        "anmil",
        "anmli",
        "anms",
        "anpa",
        "anpas",
        "anpci",
        "anpe",
        "anpi",
        "ansi",
        "ansv",
        "ant",
        "anta",
        "antifr",
        "antlo",
        "anton",
        "antrop",
        "anusca",
        "anvi",
        "anx",
        "ao",
        "ap",
        "apa",
        "apd",
        "apea",
        "apec",
        "apet",
        "api",
        "apos",
        "app.sc",
        "app",
        "apr",
        "aps",
        "apt",
        "aq",
        "ar.ind",
        "ar.rep",
        "ar",
        "arald",
        "arame",
        "arc",
        "arch",
        "archeol",
        "arci",
        "ardsu",
        "are",
        "arg",
        "aritm",
        "arpa",
        "arpat",
        "arred",
        "arrt",
        "arsia",
        "art",
        "arti min",
        "artig",
        "artigl",
        "artt",
        "as",
        "asa",
        "asae",
        "asc",
        "asci",
        "ascii",
        "ascom",
        "ascop",
        "asd",
        "ase",
        "asf",
        "asfer",
        "asg",
        "asic",
        "asifa",
        "asl",
        "asmdc",
        "asmi",
        "asp",
        "aspic",
        "aspp",
        "assi",
        "assic",
        "assol",
        "asst",
        "aster",
        "astr",
        "astrol",
        "astron",
        "at",
        "ata",
        "atb",
        "atic",
        "atm",
        "ats",
        "att",
        "attrav",
        "atv",
        "au",
        "auc",
        "aus",
        "auser",
        "aut",
        "autom",
        "av",
        "avi",
        "avis",
        "avo",
        "avv",
        "avvers",
        "awb",
        "awdp",
        "az",
        "azh",
        "b.a",
        "b2b",
        "b2c",
        "ba",
        "bafta",
        "bal",
        "ball",
        "ban",
        "banc",
        "bar",
        "bart",
        "bas",
        "bat",
        "batt",
        "bban",
        "bbc",
        "bbl",
        "bbs",
        "bbtc",
        "bcc",
        "bce",
        "bcf",
        "bdf",
        "bei",
        "bep",
        "bers",
        "bg",
        "bi",
        "bibl",
        "bic",
        "bioch",
        "biol",
        "bl",
        "bld",
        "bldg",
        "blpc",
        "bm",
        "bmps",
        "bmw",
        "bn",
        "bna",
        "bncf",
        "bncrm",
        "bni",
        "bnl",
        "bo",
        "bot",
        "bpl",
        "bpm",
        "bpn",
        "bpr",
        "br",
        "brd",
        "bre",
        "bric",
        "brig.ca",
        "brig.gen",
        "brig",
        "bros",
        "bs",
        "bsc",
        "bsp",
        "bsu",
        "bt",
        "btc",
        "btg.l",
        "btg",
        "btr",
        "bts",
        "bu",
        "bur",
        "bz",
        "c.a.p",
        "c.a",
        "c.c.p",
        "c.cost",
        "c.d a",
        "c.d",
        "c.le",
        "c.m",
        "c.opv",
        "c.p",
        "c.s",
        "c.v.d",
        "c.v",
        "c/a",
        "c/c",
        "c/pag",
        "ca.rep",
        "ca.sm",
        "ca.sz",
        "ca.uf",
        "ca",
        "caaf",
        "cab",
        "cad",
        "cae",
        "cai",
        "cal",
        "cam",
        "cap",
        "capol",
        "capt",
        "car.sc",
        "car",
        "carat",
        "card",
        "cas",
        "casaca",
        "casd",
        "cass.civ",
        "cat",
        "caus",
        "cav",
        "cavg",
        "cb",
        "cbd",
        "cbr",
        "cbs",
        "cc",
        "cca",
        "ccap",
        "ccda",
        "ccdp",
        "ccee",
        "cciaa",
        "ccie",
        "ccip",
        "cciss",
        "ccna",
        "ccnl",
        "ccnp",
        "ccpb",
        "ccs",
        "ccsp",
        "cctld",
        "cctv",
        "ccv",
        "cd",
        "cda",
        "cdma",
        "cdo",
        "cdpd",
        "cdr",
        "cds",
        "cdw",
        "ce",
        "ced",
        "cee",
        "cei",
        "cemat",
        "cenelec",
        "centr",
        "cepis",
        "ceps",
        "cept",
        "cerit",
        "cese",
        "cesis",
        "cesvot",
        "cet",
        "cf",
        "cfa",
        "cfr",
        "cg",
        "cgi",
        "cgil",
        "cgs",
        "ch",
        "chf",
        "chim. ind",
        "chim",
        "chir",
        "ci-europa",
        "ci",
        "ciber",
        "cicae",
        "cid",
        "cie",
        "cif",
        "cifej",
        "cig",
        "cigs",
        "cii",
        "cilea",
        "cilo",
        "cim",
        "cime",
        "cin",
        "cinit",
        "cio",
        "cipe",
        "cirm",
        "cisal",
        "ciscs",
        "cisd",
        "cisl",
        "cism",
        "citol",
        "cl",
        "class",
        "cli",
        "cm",
        "cm²",
        "cm³",
        "cmdr",
        "cme",
        "cmo",
        "cmr",
        "cms",
        "cmyk",
        "cn",
        "cna",
        "cnb",
        "cnc",
        "cnel",
        "cngei",
        "cni",
        "cnipa",
        "cnit",
        "cnn",
        "cnr",
        "cns",
        "cnt",
        "cnvvf",
        "co.ing",
        "co.sa",
        "co",
        "cobas",
        "coc",
        "cod. civ",
        "cod. deont. not",
        "cod. pen",
        "cod. proc. civ",
        "cod. proc. pen",
        "cod",
        "codec",
        "coi",
        "col",
        "colf",
        "coll",
        "com",
        "comdr",
        "comm",
        "comp",
        "compar",
        "compl",
        "con",
        "conai",
        "conc",
        "concl",
        "condiz",
        "confetra",
        "confitarma",
        "confr",
        "cong",
        "congeav",
        "congiunt",
        "coni",
        "coniug",
        "consec",
        "consob",
        "contab",
        "contr",
        "coreco",
        "corp",
        "corr",
        "correl",
        "corrisp",
        "cosap",
        "cospe",
        "cost",
        "costr",
        "cpc",
        "cpdel",
        "cpe",
        "cpi",
        "cpl",
        "cpt",
        "cpu",
        "cr",
        "cral",
        "credem",
        "crf",
        "cri",
        "cric",
        "cristall",
        "crm",
        "cro",
        "cron",
        "crsm",
        "crt",
        "cs",
        "csa",
        "csai",
        "csc",
        "csm",
        "csn",
        "css",
        "ct",
        "ctc",
        "cte",
        "cti",
        "ctr",
        "ctsis",
        "cuc",
        "cud",
        "cun",
        "cup",
        "cusi",
        "cvb",
        "cvbs",
        "cwt",
        "cz",
        "d.c",
        "d.i.a",
        "d",
        "dab",
        "dac",
        "dam",
        "dams",
        "dat",
        "dau",
        "db",
        "dbms",
        "dc",
        "dca",
        "dccc",
        "dda",
        "ddp",
        "ddr",
        "ddt",
        "dea",
        "decoraz",
        "dect",
        "dek",
        "denom",
        "deriv",
        "derm",
        "determ",
        "df",
        "dfp",
        "dg",
        "dga",
        "dhcp",
        "di",
        "dia",
        "dial",
        "dic",
        "dicomac",
        "dif",
        "difett",
        "dig. iv",
        "digos",
        "dimin",
        "dimostr",
        "din",
        "dipart",
        "diplom",
        "dir. amm",
        "dir. can",
        "dir. civ",
        "dir. d. lav",
        "dir. giur",
        "dir. internaz",
        "dir. it",
        "dir. pen",
        "dir. priv",
        "dir. proces",
        "dir. pub",
        "dir. rom",
        "dir",
        "disus",
        "diy",
        "dl",
        "dlf",
        "dm",
        "dm²",
        "dm³",
        "dme",
        "dmf",
        "dmo",
        "dmoz",
        "dnr",
        "dns",
        "doa",
        "doc",
        "docg",
        "dom",
        "dop",
        "dos",
        "dott",
        "dpa",
        "dpi",
        "dpl",
        "dpof",
        "dps",
        "dpt",
        "dr",
        "dra",
        "drm",
        "drs",
        "dry pt",
        "ds",
        "dslam",
        "dspn",
        "dss",
        "dtc",
        "dtmf",
        "dtp",
        "dts",
        "dv",
        "dvb-t",
        "dvb",
        "dvd",
        "dvi",
        "dwdm",
        "e.g",
        "e.p.c",
        "ead",
        "eafrd",
        "ean",
        "eap",
        "easw",
        "eb",
        "eban",
        "ebr",
        "ebri",
        "ebtn",
        "ecc",
        "eccl",
        "ecdl",
        "ecfa",
        "ecff",
        "ecg",
        "ecm",
        "econ. az",
        "econ. dom",
        "econ. pol",
        "econ",
        "ecpnm",
        "ed agg",
        "ed",
        "edge",
        "edi",
        "edil",
        "edit",
        "ef",
        "efa",
        "efcb",
        "efp",
        "efsa",
        "efta",
        "eg",
        "egiz",
        "egl",
        "egr",
        "ei",
        "eisa",
        "elab",
        "elettr",
        "elettron",
        "ellitt",
        "emap",
        "emas",
        "embr",
        "emdr",
        "emi",
        "emr",
        "en",
        "enaip",
        "enal",
        "enaoli",
        "enapi",
        "encat",
        "enclic",
        "enea",
        "enel",
        "eni",
        "enigm",
        "enit",
        "enol",
        "enpa",
        "enpaf",
        "enpals",
        "enpi",
        "enpmf",
        "ens",
        "entom",
        "epd",
        "epigr",
        "epirbs",
        "epl",
        "epo",
        "ept",
        "erc",
        "ercom",
        "ermes",
        "erp",
        "es",
        "esa",
        "escl",
        "esist",
        "eso",
        "esp",
        "estens",
        "estr. min",
        "etacs",
        "etf",
        "eti",
        "etim",
        "etn",
        "etol",
        "eu",
        "eufem",
        "eufic",
        "eula",
        "eva®",
        "f",
        "f.a",
        "f.b",
        "f.m",
        "f.p",
        "fa",
        "fabi",
        "fac",
        "facl",
        "facs",
        "fad",
        "fai",
        "faile",
        "failp",
        "failpa",
        "faisa",
        "falcri",
        "fam",
        "famar",
        "fans",
        "fao",
        "fapav",
        "faq",
        "farm",
        "fasi",
        "fasib",
        "fatt",
        "fbe",
        "fbi",
        "fc",
        "fco",
        "fcp",
        "fcr",
        "fcu",
        "fdi",
        "fe",
        "feaog",
        "feaosc",
        "feb",
        "fedic",
        "fema",
        "feoga",
        "ferr",
        "fesco",
        "fesr",
        "fess",
        "fg",
        "fi",
        "fiaf",
        "fiaip",
        "fiais",
        "fialtel",
        "fiap",
        "fiapf",
        "fiat",
        "fiavet",
        "fic",
        "ficc",
        "fice",
        "fidal",
        "fidam",
        "fidapa",
        "fieg",
        "fifa",
        "fifo",
        "fig",
        "figc",
        "figs",
        "filat",
        "filcams",
        "file",
        "filol",
        "filos",
        "fim",
        "fima",
        "fimmg",
        "fin",
        "finco",
        "fio",
        "fioto",
        "fipe",
        "fipresci",
        "fis",
        "fisar",
        "fisc",
        "fisg",
        "fisiol",
        "fisiopatol",
        "fistel",
        "fit",
        "fita",
        "fitav",
        "fits",
        "fiv",
        "fivet",
        "fivl",
        "flo",
        "flpd",
        "fluid pt",
        "fm",
        "fmcg",
        "fmi",
        "fmth",
        "fnas",
        "fnomceo",
        "fnsi",
        "fob",
        "fod",
        "folcl",
        "fon",
        "fop",
        "fotogr",
        "fp",
        "fpc",
        "fpld",
        "fr",
        "fra",
        "fs",
        "fsc",
        "fse",
        "fsf",
        "fsfi",
        "fsh",
        "ft",
        "ft²",
        "ft³",
        "ftase",
        "ftbcc",
        "fte",
        "ftp",
        "fts",
        "fuaav",
        "fut",
        "fv",
        "fvg",
        "g.fv",
        "g.u.el",
        "g.u",
        "gal",
        "gats",
        "gatt",
        "gb",
        "gc",
        "gccc",
        "gco",
        "gcost",
        "gd",
        "gdd",
        "gdf",
        "gdi",
        "gdo",
        "gdp",
        "ge",
        "gea",
        "gel",
        "gen",
        "geneal",
        "geod",
        "geofis",
        "geogr. antr",
        "geogr. fis",
        "geogr",
        "geol",
        "geom",
        "gep",
        "germ",
        "gescal",
        "gg",
        "ggv",
        "gi",
        "gia",
        "gides",
        "gift",
        "gio",
        "giorn",
        "gis",
        "gisma",
        "gismo",
        "giu",
        "gm",
        "gmdss",
        "gme",
        "gmo",
        "go",
        "gov",
        "gp",
        "gpl",
        "gprs",
        "gps",
        "gr.sel.spec",
        "gr.sel.tr",
        "gr.sqd",
        "gr",
        "gra",
        "gram",
        "grano",
        "grd",
        "grtn",
        "grv",
        "gsa",
        "gsm-r",
        "gsm",
        "gsr",
        "gtld",
        "gu",
        "guce",
        "gui",
        "gus",
        "ha",
        "haart",
        "haccp",
        "hba",
        "hcg",
        "hcrp",
        "hd-dvd",
        "hdcp",
        "hdi",
        "hdml",
        "hdtv",
        "hepa",
        "hfpa",
        "hg",
        "hifi",
        "hiperlan",
        "hiv",
        "hm",
        "hmld",
        "hon",
        "hosp",
        "hpv",
        "hr",
        "hrh",
        "hrm",
        "hrt",
        "html",
        "http",
        "hvac",
        "hz",
        "i.e",
        "i.g.m",
        "iana",
        "iasb",
        "iasc",
        "iass",
        "iat",
        "iata",
        "iatse",
        "iau",
        "iban",
        "ibid",
        "ibm",
        "icann",
        "icao",
        "icbi",
        "iccu",
        "ice",
        "icf",
        "ici",
        "icm",
        "icom",
        "icon",
        "ics",
        "icsi",
        "icstis",
        "ict",
        "icta",
        "id",
        "iden",
        "idl",
        "idraul",
        "iec",
        "iedm",
        "ieee",
        "ietf",
        "ifat",
        "ifel",
        "ifla",
        "ifrs",
        "ifto",
        "ifts",
        "ig",
        "igm",
        "igmp",
        "igp",
        "iims",
        "iipp",
        "ilm",
        "ilo",
        "ilor",
        "ils",
        "im",
        "imaie",
        "imap",
        "imc",
        "imdb",
        "imei",
        "imi",
        "imms",
        "imo",
        "imp",
        "imper",
        "imperf",
        "impers",
        "imq",
        "ims",
        "imsi",
        "in",
        "in²",
        "in³",
        "inail",
        "inca",
        "incb",
        "inci",
        "ind. agr",
        "ind. alim",
        "ind. cart",
        "ind. chim",
        "ind. cuoio",
        "ind. estratt",
        "ind. graf",
        "ind. mecc",
        "ind. tess",
        "ind",
        "indecl",
        "indef",
        "indeterm",
        "indire",
        "inea",
        "inf",
        "infea",
        "infm",
        "inform",
        "ing",
        "ingl",
        "inmarsat",
        "inpdai",
        "inpdap",
        "inpgi",
        "inps",
        "inr",
        "inran",
        "ins",
        "insp",
        "int",
        "inter",
        "intr",
        "invar",
        "invim",
        "ioma",
        "iosco",
        "ip",
        "ipab",
        "ipasvi",
        "ipi",
        "ippc",
        "ips",
        "iptv",
        "iq",
        "ira",
        "irap",
        "ircc",
        "ircs",
        "irda",
        "iref",
        "ires",
        "iron",
        "irpef",
        "irpeg",
        "irpet",
        "irreg",
        "is",
        "isae",
        "isbd",
        "isbn",
        "isc",
        "isdn",
        "isee",
        "isef",
        "isfol",
        "isg",
        "isi",
        "isia",
        "ism",
        "ismea",
        "isnart",
        "iso",
        "isp",
        "ispearmi",
        "ispel",
        "ispescuole",
        "ispesl",
        "ispo",
        "ispro",
        "iss",
        "issn",
        "istat",
        "istol",
        "isvap",
        "it",
        "iti",
        "itt",
        "ittiol",
        "itu",
        "iud",
        "iugr",
        "iulm",
        "iva",
        "iveco",
        "ivg",
        "ivr",
        "ivs",
        "iyhp",
        "j",
        "jal",
        "jit",
        "jr",
        "jv",
        "k",
        "kb",
        "kee",
        "kg",
        "kkk",
        "klm",
        "km",
        "km/h",
        "km²",
        "kmph",
        "kmq",
        "kr",
        "kw",
        "kwh",
        "l.n",
        "l'avv",
        "l'ing",
        "l",
        "la",
        "lag",
        "lan",
        "lanc",
        "larn",
        "laser",
        "lat",
        "lav. femm",
        "lav. pubbl",
        "lav",
        "laz",
        "lb",
        "lc",
        "lcca",
        "lcd",
        "le",
        "led",
        "lett",
        "lh",
        "li",
        "liaf",
        "lib",
        "lic.ord",
        "lic.strd",
        "lic",
        "licd",
        "lice",
        "lida",
        "lidci",
        "liff",
        "lifo",
        "lig",
        "liit",
        "lila",
        "lilt",
        "linfa",
        "ling",
        "lipu",
        "lis",
        "lisaac",
        "lism",
        "lit",
        "litab",
        "lnp",
        "lo",
        "loc. div",
        "loc",
        "lolo",
        "lom",
        "long",
        "lp",
        "lrm",
        "lrms",
        "lsi",
        "lsu",
        "lt",
        "ltd",
        "lu",
        "lug",
        "luiss",
        "lun",
        "lwt",
        "lww",
        "m.a",
        "m.b",
        "m.o",
        "m/s",
        "m²",
        "m³",
        "ma",
        "mac",
        "macch",
        "mag",
        "magg.(maj)",
        "magg.gen.(maj.gen.)",
        "mai",
        "maj",
        "mar.a",
        "mar.ca",
        "mar.ord",
        "mar",
        "marc",
        "mat",
        "mater",
        "max",
        "mb",
        "mbac",
        "mc",
        "mcl",
        "mcpc",
        "mcs",
        "md",
        "mdf",
        "mdp",
        "me",
        "mec",
        "mecc",
        "med",
        "mediev",
        "mef",
        "mer",
        "merc",
        "merid",
        "mesa",
        "messrs",
        "metall",
        "meteor",
        "metr",
        "metrol",
        "mg",
        "mgc",
        "mgm",
        "mi",
        "mibac",
        "mica",
        "microb",
        "mifed",
        "miglio nautico per ora",
        "miglio nautico",
        "miglio nautico²",
        "miglio²",
        "mil",
        "mile",
        "miles/h",
        "milesph",
        "min",
        "miner",
        "mips",
        "miptv",
        "mit",
        "mitol",
        "miur",
        "ml",
        "mlle",
        "mls",
        "mm",
        "mm²",
        "mme",
        "mms",
        "mn",
        "mnp",
        "mo",
        "mod",
        "mol",
        "mons",
        "morf",
        "mos",
        "mpaa",
        "mpd",
        "mpeg",
        "mpi",
        "mps",
        "mq",
        "mr",
        "mrs",
        "ms",
        "msgr",
        "mss",
        "mt",
        "mto",
        "murst",
        "mus",
        "mvds",
        "mws",
        "n.a",
        "n.b",
        "na",
        "naa",
        "nafta",
        "napt",
        "nars",
        "nasa",
        "nat",
        "natas",
        "nato",
        "nb",
        "nba",
        "nbc",
        "ncts",
        "nd",
        "nda",
        "nde",
        "ndr",
        "ndt",
        "ne",
        "ned",
        "neg",
        "neol",
        "netpac",
        "neur",
        "news!",
        "ngcc",
        "nhmf",
        "nlcc",
        "nmr",
        "no",
        "nodo",
        "nom",
        "nos",
        "nov",
        "novissdi",
        "npi",
        "nr",
        "nt",
        "nta",
        "nts",
        "ntsc",
        "nu",
        "nuct",
        "numism",
        "nwt",
        "nyc",
        "nz",
        "o.m.i",
        "oai-pmh",
        "oav",
        "oc",
        "occ",
        "occult",
        "oci",
        "ocr",
        "ocse",
        "oculist",
        "od",
        "odg",
        "odp",
        "oecd",
        "oem",
        "ofdm",
        "oft",
        "og",
        "ogg",
        "ogi",
        "ogm",
        "ohim",
        "oic",
        "oics",
        "olaf",
        "oland",
        "ole",
        "oled",
        "omi",
        "oms",
        "on",
        "ong",
        "onig",
        "onlus",
        "onomat",
        "onpi",
        "onu",
        "op",
        "opac",
        "opec",
        "opord",
        "opsosa",
        "or",
        "ord. scol",
        "ord",
        "ore",
        "oref",
        "orient",
        "ornit",
        "orogr",
        "orp",
        "ort",
        "os",
        "osa",
        "osas",
        "osd",
        "ot",
        "ote",
        "ott",
        "oz",
        "p.a",
        "p.c.c",
        "p.c",
        "p.es",
        "p.f",
        "p.m",
        "p.r",
        "p.s",
        "p.t",
        "p.v",
        "p",
        "pa",
        "pac",
        "pag./p",
        "pagg./pp",
        "pai",
        "pal",
        "paleobot",
        "paleogr",
        "paleont",
        "paleozool",
        "paletn",
        "pamr",
        "pan",
        "papir",
        "par",
        "parapsicol",
        "part",
        "partic",
        "pass",
        "pat",
        "patol",
        "pb",
        "pc",
        "pci",
        "pcm",
        "pcmcia",
        "pcs",
        "pcss",
        "pct",
        "pd",
        "pda",
        "pdf",
        "pdl",
        "pds",
        "pe",
        "pec",
        "ped",
        "pedag",
        "peg",
        "pegg",
        "per.ind",
        "pers",
        "pert",
        "pesq",
        "pet",
        "petr",
        "petrogr",
        "pfc",
        "pg",
        "pga",
        "pgp",
        "pgut",
        "ph",
        "php",
        "pi",
        "pics",
        "pie",
        "pif",
        "pii",
        "pil",
        "pime",
        "pin",
        "pine",
        "pip",
        "pir",
        "pit",
        "pitt",
        "piuss",
        "pkcs",
        "pki",
        "pko",
        "pl",
        "pli",
        "plr",
        "pm",
        "pma",
        "pmi",
        "pmr",
        "pn",
        "pnf",
        "pnl",
        "po",
        "poet",
        "pof",
        "pol",
        "pop",
        "popitt",
        "popol",
        "port",
        "pos",
        "poss",
        "post",
        "pots",
        "pp",
        "ppa",
        "ppc",
        "ppga",
        "ppp",
        "pps",
        "pptt",
        "ppv",
        "pr",
        "pra",
        "praa",
        "pref",
        "preist",
        "prep",
        "pres",
        "pret",
        "prg",
        "pri",
        "priv",
        "pro.civ",
        "prof",
        "pron",
        "pronom",
        "propr",
        "prov",
        "prs",
        "prtl",
        "prusst",
        "ps",
        "pse",
        "psi",
        "psicoan",
        "psicol",
        "pso",
        "psp",
        "pstn",
        "pt",
        "ptc",
        "pti",
        "ptsd",
        "ptt",
        "pu",
        "pug",
        "puk",
        "put",
        "pv",
        "pvb",
        "pvc",
        "pvt",
        "pz",
        "qb",
        "qcs",
        "qfd",
        "qg",
        "qi",
        "qlco",
        "qlcu",
        "qos",
        "qualif",
        "r-lan",
        "r.s",
        "ra",
        "racc",
        "radar",
        "radc",
        "radiotecn",
        "raee",
        "raf",
        "rag",
        "raid",
        "ram",
        "rar",
        "ras",
        "rass. avv. stato",
        "rc",
        "rca",
        "rcdp",
        "rcs",
        "rdc",
        "rdco",
        "rdf",
        "rdi",
        "rdp",
        "rds",
        "rdt",
        "re",
        "rea",
        "recipr",
        "recl",
        "reg",
        "region",
        "rel",
        "rem",
        "rep",
        "reps",
        "res",
        "retor",
        "rev",
        "rfi",
        "rfid",
        "rg",
        "rgb",
        "rgc",
        "rge",
        "rgi bdp",
        "rgi",
        "rgpt",
        "rgt",
        "ri",
        "riaa",
        "riaj",
        "riba",
        "ric",
        "rid",
        "rif",
        "rifl",
        "rina",
        "rip",
        "ris",
        "rit",
        "ritts",
        "rm",
        "rmn",
        "rn",
        "ro",
        "roa",
        "roc",
        "roi",
        "rom",
        "roro",
        "rov",
        "rp",
        "rpm",
        "rr",
        "rrf",
        "rs",
        "rsc",
        "rspp",
        "rss",
        "rsu",
        "rsvp",
        "rt",
        "rtdpc",
        "rtg",
        "rtn",
        "rtp",
        "rttt",
        "rvm",
        "s-dab",
        "s.a",
        "s.b.f",
        "s.n.c",
        "s.p.a",
        "s.p.m",
        "s.r.l",
        "s.ten",
        "s.v",
        "s/m",
        "sa",
        "sab",
        "saca",
        "sace",
        "sact",
        "sad",
        "sag",
        "sahm",
        "sai",
        "saisa",
        "sam",
        "san",
        "sanas",
        "sape",
        "sar",
        "sars",
        "sart",
        "sas",
        "sbaf",
        "sbas",
        "sbn",
        "sc",
        "sca.sm",
        "scherz",
        "scien",
        "scn",
        "scsi",
        "scuba",
        "scult",
        "scut",
        "sdds",
        "sdiaf",
        "sds",
        "sdsl",
        "se",
        "seat",
        "sebc",
        "sec",
        "seca",
        "secam",
        "secc",
        "see",
        "seg",
        "segg",
        "segredifesa",
        "sem",
        "sempo",
        "sen",
        "sens",
        "seo",
        "serg.magg.(sgm)",
        "serg.magg.ca",
        "serg",
        "set",
        "sfc",
        "sfis",
        "sfx",
        "sg",
        "sga",
        "sgc",
        "sgg",
        "sgml",
        "sgt",
        "si",
        "si@lt",
        "sia",
        "siae",
        "siaic",
        "siap",
        "sias",
        "sic",
        "sicav",
        "sid",
        "sido",
        "sie",
        "sif",
        "sig.na",
        "sig.ra",
        "sig",
        "sige",
        "sigg",
        "sigill",
        "sigo",
        "siia",
        "simb",
        "simbdea",
        "simg",
        "simo",
        "sin",
        "sinalv",
        "sing",
        "sins",
        "sinu",
        "siocmf",
        "siog",
        "sioi",
        "siommms",
        "siot",
        "sip",
        "sipem",
        "sips",
        "sirf",
        "sirm",
        "sis",
        "sisde",
        "sismi",
        "sissa",
        "sit",
        "siulp",
        "siusa",
        "sla",
        "sldn",
        "slm",
        "slr",
        "sm",
        "sma",
        "smau",
        "smd",
        "sme",
        "smes",
        "smm",
        "smpt",
        "sms",
        "sn",
        "snad",
        "snai",
        "snc",
        "sncci",
        "sncf",
        "sngci",
        "snit",
        "so",
        "soc",
        "sociol",
        "sogg",
        "soho",
        "soi",
        "sol",
        "somipar",
        "somm",
        "sonar",
        "sp",
        "spa",
        "spe",
        "spett",
        "spi",
        "spm",
        "spot",
        "spp",
        "spreg",
        "sq",
        "sqd",
        "sr",
        "srd",
        "srl",
        "srr",
        "ss",
        "ssi",
        "ssn",
        "ssr",
        "sss",
        "st. d. arte",
        "st. d. dir",
        "st. d. filos",
        "st. d. rel",
        "st",
        "stat",
        "stg",
        "stp",
        "stw",
        "su",
        "suap",
        "suem",
        "suff",
        "sup",
        "superl",
        "supt",
        "surg",
        "surl",
        "susm",
        "sut",
        "suv",
        "sv",
        "svga",
        "swics",
        "swift",
        "swot",
        "sxga",
        "sz",
        "t-dab",
        "t.sg",
        "ta",
        "taa",
        "tac",
        "tacan",
        "tacs",
        "taeg",
        "tai",
        "tan",
        "tar",
        "targa",
        "tav",
        "tb",
        "tbt",
        "tci",
        "tcp",
        "tcp/ip",
        "tcsm",
        "tdm",
        "tdma",
        "te",
        "tecn",
        "tecnol",
        "ted",
        "tel",
        "telecom",
        "temp",
        "ten.(lt)",
        "ten.col.(ltc)",
        "ten.gen",
        "teol",
        "term",
        "tesa",
        "tese",
        "tesol",
        "tess",
        "tet",
        "tetra",
        "tfr",
        "tft",
        "tfts",
        "tgv",
        "thx",
        "tim",
        "tipogr",
        "tir",
        "tit",
        "tld",
        "tm",
        "tmc",
        "tn",
        "to",
        "toefl",
        "ton",
        "top",
        "topog",
        "tos",
        "tosap",
        "tosc",
        "tp",
        "tpl",
        "tr",
        "trad",
        "tramat",
        "trasp",
        "ts",
        "tso",
        "tuir",
        "tuld",
        "tv",
        "twa",
        "twain",
        "u.ad",
        "u.s",
        "ucai",
        "ucca",
        "ucei",
        "ucina",
        "uclaf",
        "ucoi",
        "ucoii",
        "ucsi",
        "ud",
        "udc",
        "udi",
        "udp",
        "ue",
        "uefa",
        "uemri",
        "ufo",
        "ugc",
        "uhci",
        "uhf",
        "uht",
        "uibm",
        "uic",
        "uicc",
        "uiga",
        "uil",
        "uilps",
        "uisp",
        "uits",
        "uk",
        "ul",
        "ull",
        "uma",
        "umb",
        "ummc",
        "umss",
        "umts",
        "unac",
        "unar",
        "unasp",
        "uncem",
        "unctad",
        "undp",
        "unefa",
        "unep",
        "unesco",
        "ungh",
        "unhcr",
        "uni",
        "unicef",
        "unitec",
        "unpredep",
        "unsa",
        "upa",
        "upc",
        "urar",
        "urban",
        "url",
        "urp",
        "urss",
        "usa",
        "usb",
        "usfi",
        "usga",
        "usl",
        "usp",
        "uspi",
        "ussr",
        "utap",
        "v.brig",
        "v.cte",
        "v.m",
        "v.p",
        "v.r",
        "v.s",
        "v",
        "va",
        "vab",
        "vaio",
        "val",
        "vas",
        "vb",
        "vbr",
        "vc",
        "vcc",
        "vcr",
        "vda",
        "ve",
        "ven",
        "ves",
        "vesa",
        "veter",
        "vezz",
        "vfb",
        "vfp",
        "vfx",
        "vga",
        "vhf",
        "vhs",
        "vi",
        "via",
        "vip",
        "vis",
        "vn",
        "vo",
        "voc",
        "voip",
        "vol",
        "volg",
        "voll",
        "vor",
        "vpdn",
        "vpn",
        "vr",
        "vs",
        "vsp",
        "vt",
        "vtc",
        "vts",
        "vtt",
        "vv",
        "vvf",
        "wai",
        "wais",
        "wan",
        "wap",
        "wasp",
        "wc",
        "wcdma",
        "wcm",
        "wga",
        "wi-fi",
        "wipo",
        "wisp",
        "wll",
        "wml",
        "wms",
        "worm",
        "wp",
        "wpan",
        "wssn",
        "wto",
        "wwan",
        "wwf",
        "www",
        "wygiwys",
        "xl",
        "xml",
        "xs",
        "xxl",
        "xxs",
        "yaf",
        "yb",
        "yci",
        "yd",
        "yd²",
        "yd³",
        "ymca",
        "zat",
        "zb",
        "zcs",
        "zdf",
        "zdg",
        "zift",
        "zool",
        "zoot",
        "ztc",
        "ztl",
        "µg",
    }

    def get_lastword(self, text: str):
        lastword = re.split(r"[\s\.]+", text)[-1]
        return lastword.split("l'")[-1]



from sentencex.base import Language


class Bulgarian(Language):
    language = "bg"

    abbreviations = {
        "p.s",
        "акад",
        "ал",
        "б.р",
        "б.ред",
        "бел.а",
        "бел.пр",
        "бр",
        "бул",
        "в",
        "вж",
        "вкл",
        "вм",
        "вр",
        "г",
        "ген",
        "гр",
        "дж",
        "дм",
        "доц",
        "др",
        "ем",
        "заб",
        "зам",
        "инж",
        "к.с",
        "кв.м",
        "кв",
        "кг",
        "км",
        "кор",
        "куб.м",
        "куб",
        "л",
        "лв",
        "м.г",
        "м",
        "мин",
        "млн",
        "млрд",
        "мм",
        "н.с",
        "напр",
        "пл",
        "полк",
        "проф",
        "р",
        "рис",
        "с",
        "св",
        "сек",
        "см",
        "сп",
        "срв",
        "ст",
        "стр",
        "т.г",
        "т.е",
        "т.н",
        "т.нар",
        "т",
        "табл",
        "тел",
        "у",
        "ул",
        "фиг",
        "ха",
        "хил",
        "ч",
        "чл",
        "щ.д",
    }



import re

from sentencex.base import Language


class Finnish(Language):
    language = "fi"
    MONTHS = {
        "tammikuu",
        "helmikuu",
        "maaliskuu",
        "huhtikuu",
        "toukokuu",
        "kesäkuu",
        "heinäkuu",
        "elokuu",
        "syyskuu",
        "lokakuu",
        "marraskuu",
        "joulukuu",
    }

    abbreviations = {
        "A",
        "B",
        "C",
        "D",
        "E",
        "F",
        "G",
        "H",
        "I",
        "J",
        "K",
        "L",
        "M",
        "N",
        "O",
        "P",
        "Q",
        "R",
        "S",
        "T",
        "U",
        "V",
        "W",
        "X",
        "Y",
        "Z",
        "Å",
        "Ä",
        "Ö",
        # List of titles.
        # These are often followed by upper-case names, but do not indicate sentence breaks
        "alik",
        "alil",
        "amir",
        "apul",
        "apul.prof",
        "arkkit",
        "ass",
        "assist",
        "dipl",
        "dipl.arkkit",
        "dipl.ekon",
        "dipl.ins",
        "dipl.kielenk",
        "dipl.kirjeenv",
        "dipl.kosm",
        "dipl.urk",
        "dos",
        "Dr",
        "erikoiseläinl",
        "erikoishammasl",
        "erikoisl",
        "erikoist",
        "ev.luutn",
        "evp",
        "fil",
        "ft",
        "hallinton",
        "hallintot",
        "hammaslääket",
        "jatk",
        "jääk",
        "kansaned",
        "kapt",
        "kapt.luutn",
        "kenr",
        "kenr.luutn",
        "kenr.maj",
        "kers",
        "kirjeenv",
        "kom",
        "kom.kapt",
        "komm",
        "konst",
        "korpr",
        "luutn",
        "maist",
        "maj",
        "Mr",
        "Mrs",
        "Ms",
        "M.Sc",
        "neuv",
        "nimim",
        "Ph.D",
        "prof",
        "puh.joht",
        "pääll",
        "res",
        "san",
        "siht",
        "suom",
        "sähköp",
        "säv",
        "toht",
        "toim",
        "toim.apul",
        "toim.joht",
        "toim.siht",
        "tuom",
        "ups",
        "vänr",
        "vääp",
        "ye.ups",
        "ylik",
        "ylil",
        "ylim",
        "ylimatr",
        "yliop",
        "yliopp",
        "ylip",
        "yliv",
        # misc - odd period-ending items that NEVER indicate breaks (p.m. does NOT fall
        # into this category - it sometimes ends a sentence)
        "e.g",
        "ent",
        "esim",
        "huom",
        "i.e",
        "ilm",
        "l",
        "mm",
        "myöh",
        "nk",
        "nyk",
        "par",
        "po",
        "t",
        "v",
    }

    def continue_in_next_word(self, text_after_boundary) -> bool:
        if re.match(r"^\W*[0-9a-z]", text_after_boundary):
            return True
        next_word = text_after_boundary.strip().split(" ")[0]

        if len(next_word) == 0:
            return False
        if next_word in self.MONTHS or (next_word[0].upper() + next_word[1:] in self.MONTHS):
            return True
        return False



from .ar import Arabic
from .bg import Bulgarian
from .bn import Bengali
from .ca import Catalan
from .da import Danish
from .de import Deutsch
from .el import Greek
from .en import English
from .fi import Finnish
from .fr import French
from .gu import Gujarati
from .hi import Hindi
from .hy import Armenian
from .it import Italian
from .kk import Kazakh
from .kn import Kannada
from .ml import Malayalam
from .mr import Marathi
from .my import Burmese
from .nl import Dutch
from .or_ import Odia
from .pa import Punjabi
from .pl import Polish
from .pt import Portuguese
from .ru import Russian
from .sk import Slovak
from .ta import Tamil
from .te import Telugu

__all__ = [
    "Arabic",
    "Armenian",
    "Bengali",
    "Bulgarian",
    "Burmese",
    "Catalan",
    "Danish",
    "Deutsch",
    "Dutch",
    "English",
    "Finnish",
    "French",
    "Gujarati",
    "Greek",
    "Hindi",
    "Italian",
    "Kannada",
    "Kazakh",
    "Malayalam",
    "Marathi",
    "Odia",
    "Punjabi",
    "Polish",
    "Portuguese",
    "Russian",
    "Slovak",
    "Spanish",
    "Tamil",
    "Telugu",
]



from sentencex.base import Language


class Polish(Language):
    language = "pl"

    abbreviations = {
        "ags",
        "alb",
        "ang",
        "aor",
        "awest",
        "bałt",
        "bojkow",
        "bret",
        "brus",
        "bsł",
        "bułg",
        "c.b.d.o",
        "c.b.d.u",
        "celt",
        "chorw",
        "cs",
        "czakaw",
        "czerw",
        "czes",
        "dłuż",
        "dniem",
        "dor",
        "dubrow",
        "duń",
        "ekaw",
        "fiń",
        "franc",
        "gal",
        "germ",
        "głuż",
        "gniem",
        "goc",
        "gr",
        "grudz",
        "hebr",
        "het",
        "hol",
        "I cont",
        "ie",
        "ikaw",
        "irań",
        "irl",
        "islandz",
        "itd",
        "itd.",
        "itp",
        "jekaw",
        "kajkaw",
        "kasz",
        "kirg",
        "kwiec",
        "łac",
        "lip",
        "listop",
        "lit",
        "łot",
        "lp",
        "maced",
        "mar",
        "młpol",
        "moraw",
        "n.e",
        "nb.",
        "ngr",
        "niem",
        "nord",
        "norw",
        "np",
        "np.",
        "ok.",
        "orm",
        "oset",
        "osk",
        "p.n",
        "p.n.e",
        "p.o",
        "pazdz",
        "pers",
        "pie",
        "pod red.",
        "podhal",
        "pol",
        "połab",
        "port",
        "prekm",
        "pskow",
        "psł",
        "R cont",
        "rez",
        "rom",
        "rozdz.",
        "rum",
        "rus",
        "rys.",
        "sas",
        "sch",
        "scs",
        "serb",
        "sierp",
        "śl",
        "sła",
        "słe",
        "słi",
        "słow",
        "sp. z o.o",
        "śrdniem",
        "śrgniem",
        "śrirl",
        "stbułg",
        "stind",
        "stpol",
        "stpr",
        "str.",
        "strus",
        "stwniem",
        "stycz",
        "sztokaw",
        "szwedz",
        "t.",
        "tj.",
        "tłum.",
        "toch",
        "tur",
        "tzn",
        "ukr",
        "ul",
        "umbr",
        "wed",
        "węg",
        "wlkpol",
        "włos",
        "wrzes",
        "wyd.",
        "zakarp",
    }



from sentencex.base import Language

from .en import English

vowel_signs = {"ா", "ி", "ீ", "ு", "ூ", "ெ", "ே", "ை", "ொ", "ோ", "ௌ"}
vowels = {"அ", "ஆ", "இ", "ஈ", "உ", "ஊ", "எ", "ஏ", "ஐ", "ஒ", "ஓ", "ஔ"}
consonants = {
    "க",
    "ங",
    "ச",
    "ஞ",
    "ட",
    "ண",
    "த",
    "ந",
    "ப",
    "ம",
    "ய",
    "ர",
    "ல",
    "வ",
    "ழ",
    "ள",
    "ற",
    "ன",
}
consonant_vowels = set()

for consonant in consonants:
    for vowel_sign in vowel_signs:
        consonant_vowels.add(consonant + vowel_sign)


class Tamil(Language):
    language = "ta"

    # Writing English abbreviation like Dr as such inside Tamil is common
    abbreviations = (
        English.abbreviations.union(vowels)
        .union(consonants)
        .union(consonant_vowels)
        .union(
            {
                "ஏ",
                "பி",
                "சி",
                "டி",
                "ஈ",
                "எஃப்",
                "ஜி",
                "ஹேச்",
                "ஐ",
                "ஜே",
                "கே",
                "எல்",
                "எம்",
                "என்",
                "ஓ",
                # "பி",
                "க்யூ",
                "ஆர்",
                "எஸ்",
                # "டி",
                "யூ",
                "வி",
                "டபிள்யூ",
                "எக்ஸ்",
                "வை",
                "ஜெட்",
            }
        )
    )



import re

from sentencex.base import Language


class Danish(Language):
    language = "da"

    abbreviations = {
        "adm",
        "adr",
        "afd",
        "afs",
        "al",
        "alm",
        "ang",
        "ank",
        "anm",
        "ann",
        "ansvh",
        "apr",
        "årg",
        "årh",
        "årl",
        "arr",
        "ass",
        "att",
        "aud",
        "aug",
        "aut",
        "bd",
        "bdt",
        "bet",
        "bhk",
        "bio",
        "biol",
        "bk",
        "bl.a",
        "bot",
        "br",
        "bto",
        "ca",
        "cal",
        "cirk",
        "cit",
        "co",
        "cpr-nr",
        "cvr-nr",
        "d.å",
        "d.æ",
        "d.d",
        "d.e",
        "d.m",
        "d.s.s",
        "d.s",
        "d.y",
        "da",
        "dav",
        "dec",
        "def",
        "del",
        "dep",
        "diam",
        "din",
        "dir",
        "disp",
        "distr",
        "do",
        "dobb",
        "dr",
        "ds",
        "dvs",
        "e.b",
        "e.kr",
        "e.l",
        "e.o",
        "e.v.t",
        "eftf",
        "eftm",
        "egl",
        "eks",
        "eksam",
        "ekskl",
        "eksp",
        "ekspl",
        "el",
        "emer",
        "endv",
        "eng",
        "enk",
        "etc",
        "eur",
        "evt",
        "exam",
        "f.å",
        "f.eks",
        "f.kr",
        "f.m",
        "f.n",
        "f.o.m",
        "f.o",
        "f.s.v",
        "f.t",
        "f.v.t",
        "f",
        "fa",
        "fær",
        "fakt",
        "feb",
        "fec",
        "ff",
        "fg",
        "fhv",
        "fig",
        "fl",
        "flg",
        "fm",
        "fmd",
        "forb",
        "foreg",
        "foren",
        "forf",
        "forh",
        "fork",
        "form",
        "forr",
        "fors",
        "forsk",
        "forts",
        "fp",
        "fr",
        "frk",
        "fru",
        "fuldm",
        "fung",
        "fys",
        "g.d",
        "g.m",
        "g",
        "gd",
        "gdr",
        "gg",
        "gh",
        "gl",
        "gn",
        "gns",
        "gr",
        "grdl",
        "gross",
        "h.a",
        "h.c",
        "hdl",
        "henh",
        "henv",
        "hf",
        "hft",
        "hhv",
        "hort",
        "hosp",
        "hpl",
        "hr",
        "hrs",
        "hum",
        "i.e",
        "i",
        "ib",
        "ibid",
        "if",
        "ifm",
        "ill",
        "indb",
        "indreg",
        "ing",
        "inkl",
        "insp",
        "instr",
        "isl",
        "istf",
        "jan",
        "jf",
        "jfr",
        "jnr",
        "jr",
        "jul",
        "jun",
        "jur",
        "jvf",
        "kal",
        "kap",
        "kat",
        "kbh",
        "kem",
        "kgl",
        "kin",
        "kl",
        "kld",
        "km/t",
        "knsp",
        "komm",
        "kons",
        "korr",
        "kp",
        "kr",
        "kst",
        "kt",
        "ktr",
        "kv",
        "kvt",
        "l.c",
        "l",
        "lab",
        "lat",
        "lb.",
        "lb.nr",
        "lb",
        "lejl",
        "lgd",
        "lic",
        "lign",
        "lin",
        "ling.merc",
        "litt",
        "lø",
        "lok",
        "lrs",
        "ltr",
        "m.a.o",
        "m.fl.st",
        "m.m",
        "m",
        "m/",
        "ma",
        "mag",
        "maks",
        "mar",
        "mat",
        "matr.nr",
        "md",
        "mdl",
        "mdr",
        "mdtl",
        "med",
        "medd",
        "medflg",
        "medl",
        "merc",
        "mezz",
        "mf",
        "mfl",
        "mgl",
        "mhp",
        "mht",
        "mi",
        "mia",
        "mio",
        "ml",
        "mods",
        "modsv",
        "modt",
        "mr",
        "mrk",
        "mrs",
        "ms",
        "mul",
        "mv",
        "mvh",
        "n.br",
        "n.f",
        "n",
        "nat",
        "ned",
        "nedenn",
        "nedenst",
        "nederl",
        "nkr",
        "nl",
        "no",
        "nord",
        "nov",
        "nr",
        "nto",
        "nuv",
        "o.a",
        "ø.f",
        "o.fl.st",
        "o.g",
        "o.h",
        "o.m.a",
        "o",
        "obj",
        "obl",
        "obs",
        "odont",
        "oecon",
        "off",
        "ofl",
        "okt",
        "omg",
        "omr",
        "omtr",
        "on",
        "op.cit",
        "opg",
        "opl",
        "opr",
        "org",
        "orig",
        "osfr",
        "osv",
        "øv",
        "ovenn",
        "ovenst",
        "overs",
        "ovf",
        "øvr",
        "oz",
        "p.a",
        "p.b.v",
        "p.c",
        "p.m.v",
        "p.p",
        "p.s",
        "p.t",
        "p.v.a",
        "p.v.c",
        "p",
        "pæd",
        "par",
        "partc",
        "pass",
        "pct",
        "pd",
        "pens",
        "perf",
        "pers",
        "pg",
        "pga",
        "pgl",
        "ph.d",
        "ph",
        "pharm",
        "phil",
        "pinx",
        "pk",
        "pkt",
        "pl",
        "pluskv",
        "polit",
        "polyt",
        "port",
        "pos",
        "pp",
        "pr",
        "præd",
        "præf",
        "præp",
        "præs",
        "præt",
        "prc",
        "priv",
        "prod",
        "prof",
        "pron",
        "psych",
        "pt",
        "q.e.d",
        "rad",
        "red",
        "ref",
        "reg",
        "regn",
        "rel",
        "rep",
        "repr",
        "rest",
        "rk",
        "russ",
        "s.å",
        "s.br",
        "s.d",
        "s.e",
        "s.f",
        "s.m.b.a",
        "s.u",
        "s",
        "s/",
        "sa",
        "sædv",
        "såk",
        "sb",
        "sc",
        "scient",
        "sek",
        "sekr",
        "sem",
        "sen",
        "sep",
        "sept",
        "sg",
        "sign",
        "sj",
        "skr",
        "skt",
        "slutn",
        "sml",
        "smp",
        "sms",
        "smst",
        "sø",
        "soc",
        "sort",
        "sp",
        "spec",
        "spm",
        "spr",
        "spsk",
        "st",
        "stk",
        "str",
        "stud",
        "subj",
        "subst",
        "suff",
        "sup",
        "suppl",
        "sv",
        "t.h",
        "t.o.m",
        "t.v",
        "t",
        "tab",
        "td",
        "tdl",
        "tdr",
        "techn",
        "tekn",
        "temp",
        "th",
        "ti",
        "tidl",
        "tilf",
        "tilh",
        "till",
        "tilsv",
        "tjg",
        "tlf",
        "tlgr",
        "to",
        "tr",
        "trp",
        "tv",
        "ty",
        "u.å",
        "u.p",
        "u.st",
        "u",
        "uafh",
        "ubf",
        "ubøj",
        "udb",
        "udbet",
        "udd",
        "udg",
        "uds",
        "ugtl",
        "ulin",
        "ult",
        "undt",
        "univ",
        "v.f",
        "vær",
        "var",
        "vb",
        "vbsb",
        "vedk",
        "vedl",
        "vedr",
        "vejl",
        "vh",
        "vol",
        "vs",
        "vsa",
        "zool",
    }

    def continue_in_next_word(self, text_after_boundary) -> bool:
        if re.match(r"^\W*[0-9a-z]", text_after_boundary):
            return True



from typing import List

from . import languages
from .base import Language, Languages
from .fallbacks import LANGUAGE_FALLBACKS


def get_language_class(language: str) -> Language:
    if language in Languages.REGISTRY:
        return Languages.REGISTRY[language]

    fallbacks = LANGUAGE_FALLBACKS.get(language, ["en"])
    for fallback_language in fallbacks:
        cls = get_language_class(fallback_language)
        if cls:
            return cls


def segment(language, text: str) -> List[str]:
    """
    Segments the given text into sentences based on the specified language.

    Parameters:
        language (str): The language identifier, in ISO 639-1 format.
        text (str): The input text to be segmented.

    Returns:
        List[str]: A list of sentences.
    """
    return get_language_class(language)().segment(text)


__all__ = ["languages", "segment"]



from sentencex.base import Language

from .en import English


class Kannada(Language):
    language = "kn"
    # Writing English abbreviation like Dr as such inside Kannada is common
    abbreviations = English.abbreviations.union(
        {
            "ಎ",
            "ಬಿ",
            "ಸಿ",
            "ಡಿ",
            "ಈ",
            "ಎಫ್",
            "ಜಿ",
            "ಹೆಚ್",
            "ಐ",
            "ಜೆ",
            "ಕೆ",
            "ಎಲ್",
            "ಎಂ",
            "ಎನ್",
            "ಓ",
            "ಪಿ",
            "ಕ್ಯೂ",
            "ಆರ್",
            "ಎಸ್",
            "ಟಿ",
            "ಯೂ",
            "ವಿ",
            "ಡಬಲ್ಯೂ",
            "ಎಕ್ಸ್",
            "ವೈ",
            "ಜೆಡ್",
        }
    )



import pytest

from sentencex import segment

# ruff: noqa: E501

tests = [
    (
        "„Ich habe heute keine Zeit“, sagte die Frau und flüsterte leise: „Und auch keine Lust.“ Wir haben 1.000.000 Euro.",
        [
            "„Ich habe heute keine Zeit“, sagte die Frau und flüsterte leise: „Und auch keine Lust.“",
            "Wir haben 1.000.000 Euro.",
        ],
    ),
    (
        "Es gibt jedoch einige Vorsichtsmaßnahmen, die Du ergreifen kannst, z. B. ist es sehr empfehlenswert, dass Du Dein Zuhause von allem Junkfood befreist.",
        [
            "Es gibt jedoch einige Vorsichtsmaßnahmen, die Du ergreifen kannst, z. B. ist es sehr empfehlenswert, dass Du Dein Zuhause von allem Junkfood befreist."
        ],
    ),
    (
        "Was sind die Konsequenzen der Abstimmung vom 12. Juni?",
        ["Was sind die Konsequenzen der Abstimmung vom 12. Juni?"],
    ),
    (
        "„Ich habe heute keine Zeit“, sagte die Frau und flüsterte leise: „Und auch keine Lust.“ Wir haben 1.000.000 Euro.",
        [
            "„Ich habe heute keine Zeit“, sagte die Frau und flüsterte leise: „Und auch keine Lust.“",
            "Wir haben 1.000.000 Euro.",
        ],
    ),
    pytest.param(
        "Thomas sagte: ,,Wann kommst zu mir?” ,,Das weiß ich noch nicht“, antwortete Susi, ,,wahrscheinlich am Sonntag.“ Wir haben 1.000.000 Euro.",
        [
            "Thomas sagte: ,,Wann kommst zu mir?” ,,Das weiß ich noch nicht“, antwortete Susi, ,,wahrscheinlich am Sonntag.“",
            "Wir haben 1.000.000 Euro.",
        ],
        marks=pytest.mark.xfail,
    ),
    (
        "„Lass uns jetzt essen gehen!“, sagte die Mutter zu ihrer Freundin, „am besten zum Italiener.“",
        [
            "„Lass uns jetzt essen gehen!“, sagte die Mutter zu ihrer Freundin, „am besten zum Italiener.“"
        ],
    ),
    ("Wir haben 1.000.000 Euro.", ["Wir haben 1.000.000 Euro."]),
    ("Sie bekommen 3,50 Euro zurück.", ["Sie bekommen 3,50 Euro zurück."]),
    ("Dafür brauchen wir 5,5 Stunden.", ["Dafür brauchen wir 5,5 Stunden."]),
    ("Bitte überweisen Sie 5.300,25 Euro.", ["Bitte überweisen Sie 5.300,25 Euro."]),
    pytest.param(
        "1. Dies ist eine Punkteliste.",
        ["1. Dies ist eine Punkteliste."],
        marks=pytest.mark.xfail,
    ),
    ("Wir trafen Dr. med. Meyer in der Stadt.", ["Wir trafen Dr. med. Meyer in der Stadt."]),
    (
        "Wir brauchen Getränke, z. B. Wasser, Saft, Bier usw.",
        ["Wir brauchen Getränke, z. B. Wasser, Saft, Bier usw."],
    ),
    ("Ich kann u.a. Spanisch sprechen.", ["Ich kann u.a. Spanisch sprechen."]),
    ("Frau Prof. Schulze ist z. Z. nicht da.", ["Frau Prof. Schulze ist z. Z. nicht da."]),
    (
        "Sie erhalten ein neues Bank-Statement bzw. ein neues Schreiben.",
        ["Sie erhalten ein neues Bank-Statement bzw. ein neues Schreiben."],
    ),
    ("Z. T. ist die Lieferung unvollständig.", ["Z. T. ist die Lieferung unvollständig."]),
    ("Das finden Sie auf S. 225.", ["Das finden Sie auf S. 225."]),
    ("Sie besucht eine kath. Schule.", ["Sie besucht eine kath. Schule."]),
    (
        "Wir benötigen Zeitungen, Zeitschriften u. Ä. für unser Projekt.",
        ["Wir benötigen Zeitungen, Zeitschriften u. Ä. für unser Projekt."],
    ),
    (
        "Das steht auf S. 23, s. vorherige Anmerkung.",
        ["Das steht auf S. 23, s. vorherige Anmerkung."],
    ),
    (
        "Dies ist meine Adresse: Dr. Meier, Berliner Str. 5, 21234 Bremen.",
        ["Dies ist meine Adresse: Dr. Meier, Berliner Str. 5, 21234 Bremen."],
    ),
    (
        "Er sagte: „Hallo, wie geht´s Ihnen, Frau Prof. Müller?“",
        ["Er sagte: „Hallo, wie geht´s Ihnen, Frau Prof. Müller?“"],
    ),
    pytest.param(
        "Fit in vier Wochen\n\nDeine Anleitung für eine reine Ernährung und ein gesünderes und glücklicheres Leben\n\nRECHTLICHE HINWEISE\n\nOhne die ausdrückliche schriftliche Genehmigung der Eigentümerin von instafemmefitness, Anna Anderson, darf dieses E-Book weder teilweise noch in vollem Umfang reproduziert, gespeichert, kopiert oder auf irgendeine Weise übertragen werden. Wenn Du das E-Book auf einem öffentlich zugänglichen Computer ausdruckst, musst Du es nach dem Ausdrucken von dem Computer löschen. Jedes E-Book wird mit einem Benutzernamen und Transaktionsinformationen versehen.\n\nVerstöße gegen dieses Urheberrecht werden im vollen gesetzlichen Umfang geltend gemacht. Obgleich die Autorin und Herausgeberin alle Anstrengungen unternommen hat, sicherzustellen, dass die Informationen in diesem Buch zum Zeitpunkt der Drucklegung korrekt sind, übernimmt die Autorin und Herausgeberin keine Haftung für etwaige Verluste, Schäden oder Störungen, die durch Fehler oder Auslassungen in Folge von Fahrlässigkeit, zufälligen Umständen oder sonstigen Ursachen entstehen, und lehnt hiermit jedwede solche Haftung ab.\n\nDieses Buch ist kein Ersatz für die medizinische Beratung durch Ärzte. Der Leser/die Leserin sollte regelmäßig einen Arzt/eine Ärztin hinsichtlich Fragen zu seiner/ihrer Gesundheit und vor allem in Bezug auf Symptome, die eventuell einer ärztlichen Diagnose oder Behandlung bedürfen, konsultieren.\n\nDie Informationen in diesem Buch sind dazu gedacht, ein ordnungsgemäßes Training zu ergänzen, nicht aber zu ersetzen. Wie jeder andere Sport, der Geschwindigkeit, Ausrüstung, Gleichgewicht und Umweltfaktoren einbezieht, stellt dieser Sport ein gewisses Risiko dar. Die Autorin und Herausgeberin rät den Lesern dazu, die volle Verantwortung für die eigene Sicherheit zu übernehmen und die eigenen Grenzen zu beachten. Vor dem Ausüben der in diesem Buch beschriebenen Übungen solltest Du sicherstellen, dass Deine Ausrüstung in gutem Zustand ist, und Du solltest keine Risiken außerhalb Deines Erfahrungs- oder Trainingsniveaus, Deiner Fähigkeiten oder Deines Komfortbereichs eingehen.\nHintergrundillustrationen Urheberrecht © 2013 bei Shuttershock, Buchgestaltung und -produktion durch Anna Anderson Verfasst von Anna Anderson\nUrheberrecht © 2014 Instafemmefitness. Alle Rechte vorbehalten\n\nÜber mich",
        [
            "Fit in vier Wochen",
            "Deine Anleitung für eine reine Ernährung und ein gesünderes und glücklicheres Leben",
            "RECHTLICHE HINWEISE",
            "Ohne die ausdrückliche schriftliche Genehmigung der Eigentümerin von instafemmefitness, Anna Anderson, darf dieses E-Book weder teilweise noch in vollem Umfang reproduziert, gespeichert, kopiert oder auf irgendeine Weise übertragen werden.",
            "Wenn Du das E-Book auf einem öffentlich zugänglichen Computer ausdruckst, musst Du es nach dem Ausdrucken von dem Computer löschen.",
            "Jedes E-Book wird mit einem Benutzernamen und Transaktionsinformationen versehen.",
            "Verstöße gegen dieses Urheberrecht werden im vollen gesetzlichen Umfang geltend gemacht.",
            "Obgleich die Autorin und Herausgeberin alle Anstrengungen unternommen hat, sicherzustellen, dass die Informationen in diesem Buch zum Zeitpunkt der Drucklegung korrekt sind, übernimmt die Autorin und Herausgeberin keine Haftung für etwaige Verluste, Schäden oder Störungen, die durch Fehler oder Auslassungen in Folge von Fahrlässigkeit, zufälligen Umständen oder sonstigen Ursachen entstehen, und lehnt hiermit jedwede solche Haftung ab.",
            "Dieses Buch ist kein Ersatz für die medizinische Beratung durch Ärzte.",
            "Der Leser/die Leserin sollte regelmäßig einen Arzt/eine Ärztin hinsichtlich Fragen zu seiner/ihrer Gesundheit und vor allem in Bezug auf Symptome, die eventuell einer ärztlichen Diagnose oder Behandlung bedürfen, konsultieren.",
            "Die Informationen in diesem Buch sind dazu gedacht, ein ordnungsgemäßes Training zu ergänzen, nicht aber zu ersetzen.",
            "Wie jeder andere Sport, der Geschwindigkeit, Ausrüstung, Gleichgewicht und Umweltfaktoren einbezieht, stellt dieser Sport ein gewisses Risiko dar.",
            "Die Autorin und Herausgeberin rät den Lesern dazu, die volle Verantwortung für die eigene Sicherheit zu übernehmen und die eigenen Grenzen zu beachten.",
            "Vor dem Ausüben der in diesem Buch beschriebenen Übungen solltest Du sicherstellen, dass Deine Ausrüstung in gutem Zustand ist, und Du solltest keine Risiken außerhalb Deines Erfahrungs- oder Trainingsniveaus, Deiner Fähigkeiten oder Deines Komfortbereichs eingehen.",
            "Hintergrundillustrationen Urheberrecht © 2013 bei Shuttershock, Buchgestaltung und -produktion durch Anna Anderson Verfasst von Anna Anderson",
            "Urheberrecht © 2014 Instafemmefitness.",
            "Alle Rechte vorbehalten",
            "Über mich",
        ],
        marks=pytest.mark.xfail,
    ),
    pytest.param(
        "Es gibt jedoch einige Vorsichtsmaßnahmen, die Du ergreifen kannst, z. B. ist es sehr empfehlenswert, dass Du Dein Zuhause von allem Junkfood befreist. Ich persönlich kaufe kein Junkfood oder etwas, das nicht rein ist (ich traue mir da selbst nicht!). Ich finde jeden Vorwand, um das Junkfood zu essen, vor allem die Vorstellung, dass ich nicht mehr in Versuchung kommen werde, wenn ich es jetzt aufesse und es weg ist. Es ist schon komisch, was unser Verstand mitunter anstellt!",
        [
            "Es gibt jedoch einige Vorsichtsmaßnahmen, die Du ergreifen kannst, z. B. ist es sehr empfehlenswert, dass Du Dein Zuhause von allem Junkfood befreist.",
            "Ich persönlich kaufe kein Junkfood oder etwas, das nicht rein ist (ich traue mir da selbst nicht!).",
            "Ich finde jeden Vorwand, um das Junkfood zu essen, vor allem die Vorstellung, dass ich nicht mehr in Versuchung kommen werde, wenn ich es jetzt aufesse und es weg ist.",
            "Es ist schon komisch, was unser Verstand mitunter anstellt!",
        ],
        marks=pytest.mark.xfail,
    ),
    pytest.param(
        "Ob Sie in Hannover nur auf der Durchreise, für einen längeren Aufenthalt oder zum Besuch einer der zahlreichen Messen sind: Die Hauptstadt des Landes Niedersachsens hat viele Sehenswürdigkeiten und ist zu jeder Jahreszeit eine Reise Wert. Hannovers Ursprünge können bis zur römischen Kaiserzeit zurückverfolgt werden, und zwar durch Ausgrabungen von Tongefäßen aus dem 1. -3. Jahrhundert nach Christus, die an mehreren Stellen im Untergrund des Stadtzentrums durchgeführt wurden.",
        [
            "Ob Sie in Hannover nur auf der Durchreise, für einen längeren Aufenthalt oder zum Besuch einer der zahlreichen Messen sind: Die Hauptstadt des Landes Niedersachsens hat viele Sehenswürdigkeiten und ist zu jeder Jahreszeit eine Reise Wert.",
            "Hannovers Ursprünge können bis zur römischen Kaiserzeit zurückverfolgt werden, und zwar durch Ausgrabungen von Tongefäßen aus dem 1. -3. Jahrhundert nach Christus, die an mehreren Stellen im Untergrund des Stadtzentrums durchgeführt wurden.",
        ],
        marks=pytest.mark.xfail,
    ),
    pytest.param(
        "• 3. Seien Sie achtsam bei der Auswahl der Nahrungsmittel! \n• 4. Nehmen Sie zusätzlich Folsäurepräparate und essen Sie Fisch! \n• 5. Treiben Sie regelmäßig Sport! \n• 6. Beginnen Sie mit Übungen für die Beckenbodenmuskulatur! \n• 7. Reduzieren Sie Ihren Alkoholgenuss! \n",
        [
            "• 3. Seien Sie achtsam bei der Auswahl der Nahrungsmittel!",
            "• 4. Nehmen Sie zusätzlich Folsäurepräparate und essen Sie Fisch!",
            "• 5. Treiben Sie regelmäßig Sport!",
            "• 6. Beginnen Sie mit Übungen für die Beckenbodenmuskulatur!",
            "• 7. Reduzieren Sie Ihren Alkoholgenuss!",
        ],
        marks=pytest.mark.xfail,
    ),
    (
        "Was sind die Konsequenzen der Abstimmung vom 12. Juni?",
        ["Was sind die Konsequenzen der Abstimmung vom 12. Juni?"],
    ),
    (
        "Was pro Jahr10. Zudem pro Jahr um 0.3 %11. Der gängigen Theorie nach erfolgt der Anstieg.",
        [
            "Was pro Jahr10.",
            "Zudem pro Jahr um 0.3 %11.",
            "Der gängigen Theorie nach erfolgt der Anstieg.",
        ],
    ),
    ("s. vorherige Anmerkung.", ["s. vorherige Anmerkung."]),
    (
        "Mit Inkrafttreten des Mindestlohngesetzes (MiLoG) zum 01. Januar 2015 werden in Bezug auf den Einsatz von Leistungs.",
        [
            "Mit Inkrafttreten des Mindestlohngesetzes (MiLoG) zum 01. Januar 2015 werden in Bezug auf den Einsatz von Leistungs."
        ],
    ),
    pytest.param(
        "\n• einige Sorten Weichkäse  \n• rohes oder nicht ganz durchgebratenes Fleisch  \n• ungeputztes Gemüse und ungewaschener Salat  \n• nicht ganz durchgebratenes Hühnerfleisch, rohe oder nur weich gekochte Eier",
        [
            "\n",
            "• einige Sorten Weichkäse",
            "• rohes oder nicht ganz durchgebratenes Fleisch",
            "• ungeputztes Gemüse und ungewaschener Salat",
            "• nicht ganz durchgebratenes Hühnerfleisch, rohe oder nur weich gekochte Eier",
        ],
        marks=pytest.mark.xfail,
    ),
]


@pytest.mark.parametrize("text,expected_sentences", tests)
def test_segment(text, expected_sentences):
    assert list(segment("de", text)) == expected_sentences



import pytest

from sentencex import segment

# ruff: noqa: E501
tests = [
    (
        "Se julkaistiin singlenä 7. heinäkuuta 1997, ja se nousi listaykköseksi yhtyeen kotimaassa Britanniassa sekä Irlannissa, Suomessa, Espanjassa ja Kanadassa",
        [
            "Se julkaistiin singlenä 7. heinäkuuta 1997, ja se nousi listaykköseksi yhtyeen kotimaassa Britanniassa sekä Irlannissa, Suomessa, Espanjassa ja Kanadassa"
        ],
    ),
    (
        "Brittiläinen musiikkilehti NME valitsi lokakuussa 2011 ”D’You Know What I Meanin?” sijalle 77 listallaan, joka sisälsi 150 parasta kappaletta vuosilta 1996–2011.",
        [
            "Brittiläinen musiikkilehti NME valitsi lokakuussa 2011 ”D’You Know What I Meanin?” sijalle 77 listallaan, joka sisälsi 150 parasta kappaletta vuosilta 1996–2011."
        ],
    ),
    (
        "Netistä ladattu musiikki on otettu huomioon singlelistalla 3. lokakuuta 2007 lähtien.[13] Uudistus muutti listan luonnetta.",
        [
            "Netistä ladattu musiikki on otettu huomioon singlelistalla 3. lokakuuta 2007 lähtien.[13]",
            "Uudistus muutti listan luonnetta.",
        ],
    ),
    (
        "Radiomafia oli Yleisradion pääasiassa nuorille ja nuorille aikuisille suunnattu radiokanava, joka aloitti toimintansa vuoden 1990 radiouudistuksessa 1. kesäkuuta 1990 ja lopetti Ylen radiouudistuksen myötä 12. tammikuuta 2003.",
        [
            "Radiomafia oli Yleisradion pääasiassa nuorille ja nuorille aikuisille suunnattu radiokanava, joka aloitti toimintansa vuoden 1990 radiouudistuksessa 1. kesäkuuta 1990 ja lopetti Ylen radiouudistuksen myötä 12. tammikuuta 2003.",
        ],
    ),
    (
        "Dr. Alban (oikealta nimeltä Alban Uzoma Nwapa, s. 26. elokuuta 1957 Oguta, Brittiläinen Nigeria) on nigerialaissyntyinen ruotsalainen eurodance/rap/reggae -artisti.",
        [
            "Dr. Alban (oikealta nimeltä Alban Uzoma Nwapa, s. 26. elokuuta 1957 Oguta, Brittiläinen Nigeria) on nigerialaissyntyinen ruotsalainen eurodance/rap/reggae -artisti.",
        ],
    ),
]


@pytest.mark.parametrize("text,expected_sents", tests)
def test_segment(text, expected_sents):
    assert list(segment("fi", text)) == expected_sents



from sentencex.base import Language

from .en import English


class Telugu(Language):
    language = "te"

    # Writing English abbreviation like Dr as such inside Telugu is common
    abbreviations = English.abbreviations.union(
        {
            "ఎ",
            "బి",
            "సి",
            "డి",
            "ఈ",
            "ఎఫ్",
            "జి",
            "హెచ్",
            "ఐ",
            "జె",
            "కె",
            "ఎల్",
            "ఎం",
            "ఎన్",
            "ఓ",
            "పి",
            "క్యూ",
            "ఆర్",
            "ఎస్",
            "టి",
            "యూ",
            "వి",
            "డబ్ల్యూ",
            "ఎక్స్",
            "వై",
            "జెడ్",
        }
    )



from sentencex.base import Language


class English(Language):
    language = "en"

    abbreviations = {
        "A",
        "adj",
        "adm",
        "adv",
        "al",
        "ala",
        "alta",
        "apr",
        "arc",
        "ariz",
        "ark",
        "art",
        "assn",
        "asst",
        "attys",
        "aug",
        "ave",
        "B",
        "bart",
        "bld",
        "bldg",
        "blvd",
        "brig",
        "bros",
        "btw",
        "C",
        "cal",
        "calif",
        "capt",
        "cl",
        "cmdr",
        "co",
        "col",
        "colo",
        "comdr",
        "con",
        "conn",
        "corp",
        "cpl",
        "cres",
        "ct",
        "d.phil",
        "D",
        "dak",
        "dec",
        "del",
        "dept",
        "det",
        "dist",
        "dr.phil",
        "dr.philos",
        "dr",
        "drs",
        "e.g",
        "E",
        "ens",
        "esp",
        "esq",
        "etc",
        "exp",
        "expy",
        "ext",
        "F",
        "feb",
        "fed",
        "fig",
        "fla",
        "ft",
        "fwy",
        "fy",
        "G",
        "ga",
        "gen",
        "gov",
        "H",
        "hon",
        "hosp",
        "hr",
        "hway",
        "hwy",
        "i.e",
        "I",
        "ia",
        "id",
        "ida",
        "ill",
        "inc",
        "ind",
        "ing",
        "insp",
        "J",
        "jan",
        "jr",
        "jul",
        "jun",
        "K",
        "kan",
        "kans",
        "ken",
        "ky",
        "L",
        "la",
        "lt",
        "ltd",
        "M",
        "maj",
        "man",
        "mar",
        "mass",
        "may",
        "md",
        "me",
        "med",
        "messrs",
        "mex",
        "mfg",
        "mich",
        "min",
        "minn",
        "miss",
        "mlle",
        "mm",
        "mme",
        "mo",
        "mont",
        "mr",
        "mrs",
        "ms",
        "msgr",
        "mssrs",
        "mt",
        "mtn",
        "Nº",
        "N°",
        "No̱",
        "No",
        "N",
        "neb",
        "nebr",
        "nev",
        "no",
        "nos",
        "nov",
        "nr",
        "O",
        "oct",
        "ok",
        "okla",
        "ont",
        "op",
        "ord",
        "ore",
        "p",
        "P",
        "pa",
        "pd",
        "pde",
        "penn",
        "penna",
        "pfc",
        "ph.d",
        "ph",
        "pl",
        "plz",
        "pp",
        "prof",
        "pvt",
        "Q",
        "que",
        "R",
        "rd",
        "ref",
        "rep",
        "reps",
        "res",
        "rev",
        "rs",
        "rt",
        "S",
        "sask",
        "sec",
        "sen",
        "sens",
        "sep",
        "sept",
        "sfc",
        "sgt",
        "sr",
        "st",
        "supt",
        "surg",
        "T",
        "tce",
        "tenn",
        "tex",
        "u.s",
        "U",
        "univ",
        "usafa",
        "ut",
        "v",
        "V",
        "va",
        "ver",
        "viz",
        "vs",
        "vt",
        "W",
        "wash",
        "wis",
        "wisc",
        "wy",
        "wyo",
        "X",
        "Y",
        "yuk",
        "Z",
    }



import re

from .en import English


class Deutsch(English):
    language = "de"

    MONTHS = {
        "Januar",
        "Februar",
        "März",
        "April",
        "Mai",
        "Juni",
        "Juli",
        "August",
        "September",
        "Oktober",
        "November",
        "Dezember",
    }

    abbreviations = English.abbreviations.union(
        {
            "ä",
            "Ä",
            "adj",
            "adm",
            "adv",
            "ao.univ.prof",
            "art",
            "ass.prof",
            "ass",
            "asst",
            "b.a",
            "b.s",
            "bart",
            "bldg",
            "brig",
            "bros",
            "bse",
            "buchst",
            "bzgl",
            "bzw",
            "c.-à-d",
            "ca",
            "capt",
            "chr",
            "cmdr",
            "co",
            "col",
            "comdr",
            "con",
            "corp",
            "cpl",
            "d.h",
            "d.j",
            "dergl",
            "dgl",
            "di",
            "dipl.-ing",
            "dkr",
            "dr ",
            "ens",
            "etc",
            "ev ",
            "evtl",
            "ff",
            "g.g.a",
            "g.u",
            "gen",
            "ggf",
            "gov",
            "hon.prof",
            "hon",
            "hosp",
            "i.f",
            "i.h.v",
            "ii",
            "iii",
            "insp",
            "iv",
            "ix",
            "jun",
            "k.o",
            "kath",
            "lfd",
            "lt",
            "ltd",
            "m.e",
            "mag",
            "maj",
            "med",
            "messrs",
            "mio",
            "mlle",
            "mm",
            "mme",
            "mr",
            "mrd",
            "mrs",
            "ms",
            "msgr",
            "mwst",
            "no",
            "nos",
            "nr",
            "o.ä",
            "o.univ.-prof",
            "op",
            "ord",
            "pfc",
            "ph",
            "pp",
            "prof",
            "projektass",
            "pvt",
            "rep",
            "reps",
            "res",
            "rev",
            "rt",
            "s",
            "s.p.a",
            "sa",
            "sen",
            "sens",
            "sfc",
            "sgt",
            "sog",
            "sogen",
            "spp",
            "sr",
            "st",
            "std",
            "str  ",
            "stud.ass",
            "supt",
            "surg",
            "T",
            "u.a  ",
            "u.ä",
            "u.e",
            "u.s.w",
            "u.u",
            "univ.-doz",
            "univ.-prof",
            "univ.ass",
            "usf",
            "usw",
            "v",
            "vgl",
            "vi",
            "vii",
            "viii",
            "vs",
            "x",
            "xi",
            "xii",
            "xiii",
            "xiv",
            "xix",
            "xv",
            "xvi",
            "xvii",
            "xviii",
            "xx",
            "z.b",
            "z.t",
            "z.z",
            "z.zt",
            "zt",
            "zzt",
        }
    )

    def continue_in_next_word(self, text_after_boundary) -> bool:
        if re.match(r"^\W*[0-9a-z]", text_after_boundary):
            return True
        next_word = text_after_boundary.strip().split(" ")[0]
        next_word = next_word.strip("?!.")
        if len(next_word) == 0:
            return False
        if next_word in self.MONTHS or (next_word[0].upper() + next_word[1:] in self.MONTHS):
            return True
        return False

    def is_punctuation_between_quotes(self) -> bool:
        return True



from sentencex.base import Language


class Arabic(Language):
    language = "ar"

    abbreviations = {
        "إلخ",
        "ا. د",
        "ا.د",
        "ا.ش.ا",
        "ا",
        "ت.ب",
        "ج.ب",
        "ج.م.ع",
        "جم",
        "س.ت",
        "سم",
        "ص.ب.",
        "ص.ب",
        "كج.",
        "كلم.",
        "م.ب",
        "م",
        "ه",
    }



import pytest

from sentencex import segment

# ruff: noqa: E501
tests = [
    ("आज दसरा आहे. आज खूप शुभ दिवस आहे.", ["आज दसरा आहे.", "आज खूप शुभ दिवस आहे."]),
    ("ढग खूप गर्जत होते; पण पाऊस पडत नव्हता.", ["ढग खूप गर्जत होते; पण पाऊस पडत नव्हता."]),
    ("रमाची परीक्षा कधी आहे? अवकाश आहे अजून.", ["रमाची परीक्षा कधी आहे?", "अवकाश आहे अजून."]),
    (
        "शाब्बास, असाच अभ्यास कर! आणि मग तुला नक्की यश मिळणार.",
        ["शाब्बास, असाच अभ्यास कर!", "आणि मग तुला नक्की यश मिळणार."],
    ),
    (
        '"आपली आपण करी स्तुती तो एक मूर्ख" असे समर्थ रामदासस्वामी म्हणतात.',
        ['"आपली आपण करी स्तुती तो एक मूर्ख" असे समर्थ रामदासस्वामी म्हणतात.'],
    ),
]


@pytest.mark.parametrize("text,expected_sents", tests)
def test_segment(text, expected_sents):
    assert list(segment("mr", text)) == expected_sents



import pytest

from sentencex import segment

# ruff: noqa: E501
tests = [
    pytest.param(
        "سؤال وجواب: ماذا حدث بعد الانتخابات الايرانية؟ طرح الكثير من التساؤلات غداة ظهور نتائج الانتخابات الرئاسية الايرانية التي أججت مظاهرات واسعة واعمال عنف بين المحتجين على النتائج ورجال الامن. يقول معارضو الرئيس الإيراني إن الطريقة التي اعلنت بها النتائج كانت مثيرة للاستغراب.",
        [
            "سؤال وجواب:",
            "ماذا حدث بعد الانتخابات الايرانية؟",
            "طرح الكثير من التساؤلات غداة ظهور نتائج الانتخابات الرئاسية الايرانية التي أججت مظاهرات واسعة واعمال عنف بين المحتجين على النتائج ورجال الامن.",
            "يقول معارضو الرئيس الإيراني إن الطريقة التي اعلنت بها النتائج كانت مثيرة للاستغراب.",
        ],
        marks=pytest.mark.xfail,
    ),
    # has unicode character. Need arabic language knowledge to resolve the issue
    pytest.param(
        "وقال د‪.‬ ديفيد ريدي و الأطباء الذين كانوا يعالجونها في مستشفى برمنجهام إنها كانت تعاني من أمراض أخرى. وليس معروفا ما اذا كانت قد توفيت بسبب اصابتها بأنفلونزا الخنازير.",
        [
            "وقال د‪.‬ ديفيد ريدي و الأطباء الذين كانوا يعالجونها في مستشفى برمنجهام إنها كانت تعاني من أمراض أخرى.",
            "وليس معروفا ما اذا كانت قد توفيت بسبب اصابتها بأنفلونزا الخنازير.",
        ],
        marks=pytest.mark.xfail,
    ),
    (
        "ومن المنتظر أن يكتمل مشروع خط أنابيب نابوكو البالغ طوله 3300 كليومترا في 12‪/‬08‪/‬2014 بتكلفة تُقدر بـ 7.9 مليارات يورو أي نحو 10.9 مليارات دولار. ومن المقرر أن تصل طاقة ضخ الغاز في المشروع 31 مليار متر مكعب انطلاقا من بحر قزوين مرورا بالنمسا وتركيا ودول البلقان دون المرور على الأراضي الروسية.",
        [
            "ومن المنتظر أن يكتمل مشروع خط أنابيب نابوكو البالغ طوله 3300 كليومترا في 12‪/‬08‪/‬2014 بتكلفة تُقدر بـ 7.9 مليارات يورو أي نحو 10.9 مليارات دولار.",
            "ومن المقرر أن تصل طاقة ضخ الغاز في المشروع 31 مليار متر مكعب انطلاقا من بحر قزوين مرورا بالنمسا وتركيا ودول البلقان دون المرور على الأراضي الروسية.",
        ],
    ),
    pytest.param(
        "الاحد, 21 فبراير/ شباط, 2010, 05:01 GMT الصنداي تايمز: رئيس الموساد قد يصبح ضحية الحرب السرية التي شتنها بنفسه. العقل المنظم هو مئير داجان رئيس الموساد الإسرائيلي الذي يشتبه بقيامه باغتيال القائد الفلسطيني في حركة حماس محمود المبحوح في دبي.",
        [
            "الاحد, 21 فبراير/ شباط, 2010, 05:01 GMT الصنداي تايمز:",
            "رئيس الموساد قد يصبح ضحية الحرب السرية التي شتنها بنفسه.",
            "العقل المنظم هو مئير داجان رئيس الموساد الإسرائيلي الذي يشتبه بقيامه باغتيال القائد الفلسطيني في حركة حماس محمود المبحوح في دبي.",
        ],
        marks=pytest.mark.xfail,
    ),
    pytest.param(
        "عثر في الغرفة على بعض أدوية علاج ارتفاع ضغط الدم، والقلب، زرعها عملاء الموساد كما تقول مصادر إسرائيلية، وقرر الطبيب أن الفلسطيني قد توفي وفاة طبيعية ربما إثر نوبة قلبية، وبدأت مراسم الحداد عليه",
        [
            "عثر في الغرفة على بعض أدوية علاج ارتفاع ضغط الدم، والقلب،",
            "زرعها عملاء الموساد كما تقول مصادر إسرائيلية،",
            "وقرر الطبيب أن الفلسطيني قد توفي وفاة طبيعية ربما إثر نوبة قلبية،",
            "وبدأت مراسم الحداد عليه",
        ],
        marks=pytest.mark.xfail,
    ),
]


@pytest.mark.parametrize("text,expected_sentences", tests)
def test_segment(text, expected_sentences):
    assert list(segment("ar", text)) == expected_sentences
